@@ -297,16 +297,16 @@ QString Device::storageDescription() const
         if ((mediumTypes & Solid::OpticalDrive::Dvdr) && (mediumTypes & Solid::OpticalDrive::Dvdplusr))
         {
             if(mediumTypes & Solid::OpticalDrive::Dvdplusdl)
-                second = QObject::trUtf8("/DVD±R DL", "Second item of %1%2 Drive sentence");
+                second = QObject::tr("/DVD±R DL", "Second item of %1%2 Drive sentence");
             else
-                second = QObject::trUtf8("/DVD±R", "Second item of %1%2 Drive sentence");
+                second = QObject::tr("/DVD±R", "Second item of %1%2 Drive sentence");
         }
         if ((mediumTypes & Solid::OpticalDrive::Dvdrw) && (mediumTypes & Solid::OpticalDrive::Dvdplusrw))
         {
             if((mediumTypes & Solid::OpticalDrive::Dvdplusdl) || (mediumTypes & Solid::OpticalDrive::Dvdplusdlrw))
-                second = QObject::trUtf8("/DVD±RW DL", "Second item of %1%2 Drive sentence");
+                second = QObject::tr("/DVD±RW DL", "Second item of %1%2 Drive sentence");
             else
-                second = QObject::trUtf8("/DVD±RW", "Second item of %1%2 Drive sentence");
+                second = QObject::tr("/DVD±RW", "Second item of %1%2 Drive sentence");
         }
         if (mediumTypes & Solid::OpticalDrive::Bd)
             second = QCoreApplication::translate("", "/BD-ROM", "Second item of %1%2 Drive sentence");
