@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -188,7 +188,7 @@ void ViewSelector::setCurrentIndex(int index)
 
 void ViewSelector::wheelEvent(QWheelEvent *ev)
 {
-    int numDegrees = ev->delta() / 8;
+    int numDegrees = ev->angleDelta().y() / 8;
     int numSteps = numDegrees / 15;
     if (numSteps > 0) {
         for (int i = 0; i < numSteps; ++i) {
@@ -269,7 +269,7 @@ ContextWidget::ContextWidget(QWidget *parent)
     artist = new ArtistView(standardContext);
     album = new AlbumView(standardContext);
     song = new SongView(standardContext);
-    minWidth=album->picSize().width()*2.5;
+    minWidth=album->width()+artist->width()+song->width();
 
     artist->addEventFilter(this);
     album->addEventFilter(this);
@@ -543,7 +543,7 @@ void ContextWidget::paintEvent(QPaintEvent *e)
     }
 }
 
-void ContextWidget::setFade(float value)
+void ContextWidget::setFade(double value)
 {
     if (fadeValue!=value) {
         fadeValue = value;
