@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -104,7 +104,7 @@ public:
     void showEvent(QShowEvent *e) override;
     void paintEvent(QPaintEvent *e) override;
     float fade() { return fadeValue; }
-    void setFade(float value);
+    void setFade(double value);
     void updateImage(QImage img);
     void search();
 
