@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -216,7 +216,7 @@ void SongView::edit()
         QFile file(lyricsFile);
         if (file.open(QIODevice::ReadWrite|QIODevice::Text)) {
             QTextStream stream(&file);
-            stream << tr("Failed to locate lyrics") << endl;
+            stream << tr("Failed to locate lyrics") << CANTATA_ENDL;
         }
     }
     QDesktopServices::openUrl(QUrl::fromLocalFile(lyricsFile));
@@ -478,9 +478,7 @@ static QString createRow(const QString &key, const QString &value, bool htmlEsca
 {
     return value.isEmpty()
             ? QString()
-            : htmlEscape
-                ? QString("<tr><td>%1:&nbsp;</td><td>%2</td></tr>").arg(key).arg(fixNewLine(value).toHtmlEscaped())
-                : QString("<tr><td>%1:&nbsp;</td><td>%2</td></tr>").arg(key).arg(fixNewLine(value));
+            : QString("<tr><td>%1:&nbsp;</td><td>%2</td></tr>").arg(key).arg(fixNewLine(htmlEscape ? value.toHtmlEscaped() : value));
 }
 
 struct MapEntry {
@@ -615,6 +613,7 @@ void SongView::loadMetadata()
         addIfNotEmpty(tags, pos++, tr("Album"), currentSong.album);
         addIfNotEmpty(tags, pos++, tr("Track number"), 0==currentSong.track ? QString() : QString::number(currentSong.track));
         addIfNotEmpty(tags, pos++, tr("Disc number"), 0==currentSong.disc ? QString() : QString::number(currentSong.disc));
+        addIfNotEmpty(tags, pos++, tr("Grouping"), currentSong.grouping());
         addIfNotEmpty(tags, pos++, tr("Duration"), 0==currentSong.time ? QString() : Utils::formatTime(currentSong.time));
         addIfNotEmpty(tags, pos++, tr("Genre"), currentSong.displayGenre());
         addIfNotEmpty(tags, pos++, tr("Year"), 0==currentSong.track ? QString() : QString::number(currentSong.year));
@@ -917,7 +916,6 @@ void SongView::setMode(Mode m)
     mode=m;
     bool fileExists=Mode_Display==m && !lyricsFile.isEmpty() && QFileInfo(lyricsFile).isWritable();
     delAction->setEnabled(fileExists);
-    refreshAction->setEnabled(fileExists);
     if (scrollAction->isChecked()) {
         if (Mode_Display==mode) {
             scroll();
