@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -116,10 +116,7 @@ private:
     int currentRequest;
     Action *scrollAction;
     Action *refreshAction;
-    Action *searchAction;
     Action *editAction;
-    Action *saveAction;
-    Action *cancelEditAction;
     Action *delAction;
     Mode mode;
     QString lyricsFile;
