@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /* This file is part of Clementine.
@@ -57,7 +57,7 @@ public:
     QString getName() const { return name; }
     QString displayName() const;
     int getRelevance() const { return relevance; }
-    void fetchInfo(int id, const Song &metadata);
+    void fetchInfo(int id, Song metadata, bool removeThe=false);
     bool isEnabled() const { return enabled; }
     void setEnabled(bool e) { enabled = e; }
     void abort();
