@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -61,7 +61,7 @@ static QString fixWikiLink(const QUrl &url)
     QString fixed(path);
     fixed=fixed.replace("/wiki"+wikipediaSpecialExport(lang), "/wiki/");
     if (path==fixed) {
-        QStringList parts=fixed.split("/", QString::SkipEmptyParts);
+        QStringList parts=fixed.split("/", CANTATA_SKIP_EMPTY);
         if (parts.length()>1) {
             parts.removeAt(1);
             fixed=parts.join("/");
@@ -249,6 +249,7 @@ static QString wikiToHtml(QString answer, bool introOnly, const QUrl &url)
     }
     answer.replace("&amp;nbsp;", " ");
     answer.replace("&ndash;", "-");
+    answer.replace("&amp;mdash;", "—");
     answer.replace("<br><h", "<h");
     if (introOnly) {
         end=answer.indexOf("==", 3);
@@ -467,15 +468,15 @@ void WikipediaEngine::getPage(const QStringList &query, Mode mode, const QString
     switch (mode) {
     default:
     case Artist:
-        patterns=tr("artist|band|singer|vocalist|musician", "Search pattern for an artist or band, separated by |").split("|", QString::SkipEmptyParts);
+        patterns=tr("artist|band|singer|vocalist|musician", "Search pattern for an artist or band, separated by |").split("|", CANTATA_SKIP_EMPTY);
         englishPatterns=QString(QLatin1String("artist|band|singer|vocalist|musician")).split("|");
         break;
     case Album:
-        patterns=tr("album|score|soundtrack", "Search pattern for an album, separated by |").split("|", QString::SkipEmptyParts);
+        patterns=tr("album|score|soundtrack", "Search pattern for an album, separated by |").split("|", CANTATA_SKIP_EMPTY);
         englishPatterns=QString(QLatin1String("album|score|soundtrack")).split("|");
         break;
     case Track:
-//        patterns=trc("Search pattern for a song, separated by |", "song|track").split("|", QString::SkipEmptyParts);
+//        patterns=trc("Search pattern for a song, separated by |", "song|track").split("|", CANTATA_SKIP_EMPTY);
 //        englishPatterns=QString(QLatin1String("song|track")).split("|");
         break;
     }
