@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2017-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2017-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -22,6 +22,7 @@
  */
 
 #include "librarydb.h"
+#include "support/utils.h"
 #include <QCoreApplication>
 #include <QSqlDatabase>
 #include <QSqlError>
@@ -70,14 +71,14 @@ static bool albumsSortAlArYr(const LibraryDb::Album &a, const LibraryDb::Album &
 {
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    int cmp=an.localeAwareCompare(bn);
+    int cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    cmp=aa.localeAwareCompare(ba);
+    cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -88,14 +89,14 @@ static bool albumsSortArAlYr(const LibraryDb::Album &a, const LibraryDb::Album &
 {
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    int cmp=aa.localeAwareCompare(ba);
+    int cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    cmp=an.localeAwareCompare(bn);
+    cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -107,7 +108,7 @@ static bool albumsSortAlYrAr(const LibraryDb::Album &a, const LibraryDb::Album &
 {
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    int cmp=an.localeAwareCompare(bn);
+    int cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -118,14 +119,14 @@ static bool albumsSortAlYrAr(const LibraryDb::Album &a, const LibraryDb::Album &
 
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    return aa.localeAwareCompare(ba)<0;
+    return Utils::compare(aa, ba)<0;
 }
 
 static bool albumsSortArYrAl(const LibraryDb::Album &a, const LibraryDb::Album &b)
 {
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    int cmp=aa.localeAwareCompare(ba);
+    int cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -136,7 +137,7 @@ static bool albumsSortArYrAl(const LibraryDb::Album &a, const LibraryDb::Album &
 
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    return an.localeAwareCompare(bn)<0;
+    return Utils::compare(an, bn)<0;
 }
 
 static bool albumsSortYrAlAr(const LibraryDb::Album &a, const LibraryDb::Album &b)
@@ -147,14 +148,14 @@ static bool albumsSortYrAlAr(const LibraryDb::Album &a, const LibraryDb::Album &
 
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    int cmp=an.localeAwareCompare(bn);
+    int cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    return aa.localeAwareCompare(ba)<0;
+    return Utils::compare(aa, ba)<0;
 }
 
 static bool albumsSortYrArAl(const LibraryDb::Album &a, const LibraryDb::Album &b)
@@ -165,14 +166,14 @@ static bool albumsSortYrArAl(const LibraryDb::Album &a, const LibraryDb::Album &
 
     const QString &aa=a.artistSort.isEmpty() ? a.artist : a.artistSort;
     const QString &ba=b.artistSort.isEmpty() ? b.artist : b.artistSort;
-    int cmp=aa.localeAwareCompare(ba);
+    int cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString &an=a.sort.isEmpty() ? a.name : a.sort;
     const QString &bn=b.sort.isEmpty() ? b.name : b.sort;
-    return an.localeAwareCompare(bn)<0;
+    return Utils::compare(an, bn)<0;
 }
 
 static bool albumsSortModified(const LibraryDb::Album &a, const LibraryDb::Album &b)
@@ -186,11 +187,11 @@ static bool albumsSortModified(const LibraryDb::Album &a, const LibraryDb::Album
 static bool songSort(const Song &a, const Song &b)
 {
     if (Song::SingleTracks==a.type && Song::SingleTracks==b.type) {
-        int cmp=a.title.localeAwareCompare(b.title);
+        int cmp=Utils::compare(a.title, b.title);
         if (0!=cmp) {
             return cmp<0;
         }
-        cmp=a.artist.localeAwareCompare(b.artist);
+        cmp=Utils::compare(a.artist, b.artist);
         if (0!=cmp) {
             return cmp<0;
         }
@@ -205,15 +206,15 @@ static bool songSort(const Song &a, const Song &b)
     if (a.displayYear()!=b.displayYear()) {
         return a.displayYear()<b.displayYear();
     }
-    int cmp=a.title.localeAwareCompare(b.title);
+    int cmp=Utils::compare(a.title, b.title);
     if (0!=cmp) {
         return cmp<0;
     }
-    cmp=a.name().localeAwareCompare(b.name());
+    cmp=Utils::compare(a.name(), b.name());
     if (0!=cmp) {
         return cmp<0;
     }
-    cmp=a.displayGenre().localeAwareCompare(b.displayGenre());
+    cmp=Utils::compare(a.displayGenre(), b.displayGenre());
     if (0!=cmp) {
         return cmp<0;
     }
@@ -227,14 +228,14 @@ static bool songsSortAlAr(const Song &a, const Song &b)
 {
     const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
     const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-    int cmp=an.localeAwareCompare(bn);
+    int cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
     const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-    cmp=aa.localeAwareCompare(ba);
+    cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -249,14 +250,14 @@ static bool songsSortArAl(const Song &a, const Song &b)
 {
     const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
     const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-    int cmp=aa.localeAwareCompare(ba);
+    int cmp=Utils::compare(aa, ba);
     if (cmp!=0) {
         return cmp<0;
     }
 
     const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
     const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-    cmp=an.localeAwareCompare(bn);
+    cmp=Utils::compare(an, bn);
     if (cmp!=0) {
         return cmp<0;
     }
@@ -271,7 +272,7 @@ static bool songsSortArAl(const Song &a, const Song &b)
 //{
 //    const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
 //    const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-//    int cmp=an.localeAwareCompare(bn);
+//    int cmp=Utils::compare(an, bn);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -282,7 +283,7 @@ static bool songsSortArAl(const Song &a, const Song &b)
 
 //    const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
 //    const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-//    cmp=aa.localeAwareCompare(ba);
+//    cmp=Utils::compare(aa, ba);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -294,7 +295,7 @@ static bool songsSortArAl(const Song &a, const Song &b)
 //{
 //    const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
 //    const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-//    int cmp=aa.localeAwareCompare(ba);
+//    int cmp=Utils::compare(aa, ba);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -305,7 +306,7 @@ static bool songsSortArAl(const Song &a, const Song &b)
 
 //    const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
 //    const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-//    cmp=an.localeAwareCompare(bn);
+//    cmp=Utils::compare(an, bn);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -321,14 +322,14 @@ static bool songsSortArAl(const Song &a, const Song &b)
 
 //    const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
 //    const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-//    int cmp=an.localeAwareCompare(bn);
+//    int cmp=Utils::compare(an, bn);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
 
 //    const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
 //    const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-//    cmp=aa.localeAwareCompare(ba);
+//    cmp=Utils::compare(aa, ba);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -344,14 +345,14 @@ static bool songsSortArAl(const Song &a, const Song &b)
 
 //    const QString aa=a.hasArtistSort() ? a.artistSort() : a.albumArtist();
 //    const QString ba=b.hasArtistSort() ? b.artistSort() : b.albumArtist();
-//    int cmp=aa.localeAwareCompare(ba);
+//    int cmp=Utils::compare(aa, ba);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
 
 //    const QString an=a.hasAlbumSort() ? a.albumSort() : a.album;
 //    const QString bn=b.hasAlbumSort() ? b.albumSort() : b.album;
-//    cmp=an.localeAwareCompare(bn);
+//    cmp=Utils::compare(an, bn);
 //    if (cmp!=0) {
 //        return cmp<0;
 //    }
@@ -643,6 +644,9 @@ bool LibraryDb::init(const QString &dbFile)
 
 void LibraryDb::insertSong(const Song &s)
 {
+    if (!db) {
+        return;
+    }
     if (!insertSongQuery) {
         insertSongQuery=new QSqlQuery(*db);
         insertSongQuery->prepare("insert into songs(file, artist, artistId, albumArtist, artistSort, composer, album, albumId, albumSort, title, genre1, genre2, genre3, genre4, track, disc, time, year, origYear, type, lastModified) "
@@ -677,6 +681,10 @@ void LibraryDb::insertSong(const Song &s)
 QList<LibraryDb::Genre> LibraryDb::getGenres()
 {
     DBUG;
+    QList<LibraryDb::Genre> genres;
+    if (!db) {
+        return genres;
+    }
     QMap<QString, QSet<QString> > map;
     if (0!=currentVersion && db) {
         QString queryStr("distinct ");
@@ -699,7 +707,6 @@ QList<LibraryDb::Genre> LibraryDb::getGenres()
         }
     }
 
-    QList<LibraryDb::Genre> genres;
     QMap<QString, QSet<QString> >::ConstIterator it=map.constBegin();
     QMap<QString, QSet<QString> >::ConstIterator end=map.constEnd();
     for (; it!=end; ++it) {
@@ -713,6 +720,10 @@ QList<LibraryDb::Genre> LibraryDb::getGenres()
 QList<LibraryDb::Artist> LibraryDb::getArtists(const QString &genre)
 {
     DBUG << genre;
+    QList<LibraryDb::Artist> artists;
+    if (!db) {
+        return artists;
+    }
     QMap<QString, QString> sortMap;
     QMap<QString, int> albumMap;
     if (0!=currentVersion && db) {
@@ -732,7 +743,6 @@ QList<LibraryDb::Artist> LibraryDb::getArtists(const QString &genre)
         }
     }
 
-    QList<LibraryDb::Artist> artists;
     QMap<QString, int>::ConstIterator it=albumMap.constBegin();
     QMap<QString, int>::ConstIterator end=albumMap.constEnd();
     for (; it!=end; ++it) {
@@ -748,6 +758,9 @@ QList<LibraryDb::Album> LibraryDb::getAlbums(const QString &artistId, const QStr
     timer.start();
     DBUG << artistId << genre;
     QList<Album> albums;
+    if (!db) {
+        return albums;
+    }
     if (0!=currentVersion && db) {
         bool wantModified=AS_Modified==sort;
         bool wantArtist=artistId.isEmpty();
@@ -839,7 +852,7 @@ QList<LibraryDb::Album> LibraryDb::getAlbums(const QString &artistId, const QStr
         QMap<QString, QSet<QString> >::ConstIterator aEnd = albumIdArtists.constEnd();
         for(; aIt!=aEnd; ++aIt) {
             if (aIt.value().count()>1) {
-                QStringList artists = aIt.value().toList();
+                QStringList artists = aIt.value().values();
                 artists.sort();
                 Album &al = entries.find(aIt.key()).value();
                 al.artist = artists.join(", ");
@@ -881,10 +894,13 @@ QList<LibraryDb::Album> LibraryDb::getAlbums(const QString &artistId, const QStr
     return albums;
 }
 
-QList<Song> LibraryDb::getTracks(const QString &artistId, const QString &albumId, const QString &genre, AlbumSort sort, bool useFilter)
+QList<Song> LibraryDb::getTracks(const QString &artistId, const QString &albumId, const QString &genre, AlbumSort sort, bool useFilter, int maxTracks)
 {
     DBUG << artistId << albumId << genre << sort;
     QList<Song> songs;
+    if (!db) {
+        return songs;
+    }
     if (0!=currentVersion && db) {
         SqlQuery query("*", *db);
         if (useFilter) {
@@ -901,6 +917,9 @@ QList<Song> LibraryDb::getTracks(const QString &artistId, const QString &albumId
         } else if (useFilter && !genreFilter.isEmpty()) {
             query.addWhere("genre", genreFilter);
         }
+        if (maxTracks != 1) {
+            query.setLimit(maxTracks);
+        }
         query.exec();
         DBUG << query.executedQuery();
         while (query.next()) {
