@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2017-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2017-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -29,6 +29,7 @@
 #include <QMap>
 #include <QElapsedTimer>
 #include "mpd-interface/song.h"
+#include "support/utils.h"
 #include <time.h>
 
 class QSqlDatabase;
@@ -72,7 +73,7 @@ public:
             if (constNullGenre==name) {
                 return constNullGenre!=o.name;
             }
-            return name.localeAwareCompare(o.name)<0;
+            return Utils::compare(name, o.name)<0;
         }
     };
 
@@ -89,7 +90,7 @@ public:
             const QString &field=sort.isEmpty() ? name : sort;
             const QString &ofield=o.sort.isEmpty() ? o.name : o.sort;
 
-            return field.localeAwareCompare(ofield)<0;
+            return Utils::compare(field, ofield)<0;
         }
     };
 
@@ -121,7 +122,7 @@ public:
     QList<Genre> getGenres();
     QList<Artist> getArtists(const QString &genre=QString());
     QList<Album> getAlbums(const QString &artistId=QString(), const QString &genre=QString(), AlbumSort sort=AS_YrAlAr);
-    QList<Song> getTracks(const QString &artistId, const QString &albumId, const QString &genre=QString(), AlbumSort sort=AS_YrAlAr, bool useFilter=true);
+    QList<Song> getTracks(const QString &artistId, const QString &albumId, const QString &genre=QString(), AlbumSort sort=AS_YrAlAr, bool useFilter=true, int maxTracks=-1);
     QList<Song> getTracks(int rowFrom, int count);
     int trackCount();
     QList<Song> songs(const QStringList &files, bool allowPlaylists=false) const;
