@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -374,7 +374,7 @@ void MtpConnection::updateLibrary(const DeviceOptions &opts)
         s.populateSorts();
         #ifdef MTP_FAKE_ALBUMARTIST_SUPPORT
         if (getAlbumArtistFromPath) {
-            QStringList folderParts=(*folder).path.split('/', QString::SkipEmptyParts);
+            QStringList folderParts=(*folder).path.split('/', CANTATA_SKIP_EMPTY);
             if (folderParts.length()>=3) {
                 // Path should be "Music/${AlbumArtist}/${Album}"
                 int artistPath=1;
@@ -772,6 +772,10 @@ static QTemporaryFile * saveImageToTemp(const QImage &img, const QString &name)
 void MtpConnection::putSong(const Song &s, bool fixVa, const DeviceOptions &opts, bool overwrite, bool copyCover)
 {
     int status=Device::Failed;
+    if (storage.isEmpty()) {
+        emit putSongStatus(status, QString(), false, false);
+        return;
+    }
     bool fixedVa=false;
     bool embedCoverImage=Device::constEmbedCover==opts.coverName;
     bool copiedCover=false;
@@ -822,7 +826,7 @@ void MtpConnection::putSong(const Song &s, bool fixVa, const DeviceOptions &opts
         meta->parent_id=folderId=store.musicFolderId;
         meta->storage_id=store.id;
         destName=store.musicPath+opts.createFilename(song);
-        QStringList dirs=destName.split('/', QString::SkipEmptyParts);
+        QStringList dirs=destName.split('/', CANTATA_SKIP_EMPTY);
         if (dirs.count()>1) {
             destName=dirs.takeLast();
             meta->parent_id=folderId=checkFolderStructure(dirs, store);
@@ -1057,28 +1061,29 @@ bool MtpConnection::removeFolder(uint32_t folderId)
 
 void MtpConnection::cleanDirs(const QSet<QString> &dirs)
 {
-    for (const QString &d: dirs) {
-        Path path=decodePath(d);
-        Storage &store=getStorage(path.storage);
-        if (0==store.musicFolderId) {
-            continue;
-        }
-        uint32_t folderId=path.parent;
-        while (0!=folderId && folderId!=store.musicFolderId) {
-            QMap<uint32_t, Folder>::iterator it=folderMap.find(folderId);
-            if (it!=folderMap.end()) {
-                if (removeFolder(folderId)) {
-                    folderId=(*it).parentId;
-                    folderMap.erase(it);
+    if (!storage.isEmpty()) {
+        for (const QString &d: dirs) {
+            Path path=decodePath(d);
+            Storage &store=getStorage(path.storage);
+            if (0==store.musicFolderId) {
+                continue;
+            }
+            uint32_t folderId=path.parent;
+            while (0!=folderId && folderId!=store.musicFolderId) {
+                QMap<uint32_t, Folder>::iterator it=folderMap.find(folderId);
+                if (it!=folderMap.end()) {
+                    if (removeFolder(folderId)) {
+                        folderId=(*it).parentId;
+                        folderMap.erase(it);
+                    } else {
+                        break;
+                    }
                 } else {
                     break;
                 }
-            } else {
-                break;
             }
         }
     }
-
     updateStorage();
     emit cleanDirsStatus(true);
 }
