@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -288,7 +288,7 @@ void RemoteFsDevice::mount()
                  << QLatin1String("-o") << QLatin1String("ServerAliveInterval=15");
             //<< QLatin1String("-o") << QLatin1String("Ciphers=arcfour");
             if (!details.extraOptions.isEmpty()) {
-                args << details.extraOptions.split(' ', QString::SkipEmptyParts);
+                args << details.extraOptions.split(' ', CANTATA_SKIP_EMPTY);
             }
         } else {
             emit error(tr("\"sshfs\" is not installed!").replace("sshfs", "setsid")); // TODO: 2.4 use correct string!
@@ -530,11 +530,6 @@ bool RemoteFsDevice::canPlaySongs() const
     return details.isLocalFile() || HttpServer::self()->isAlive();
 }
 
-static inline QString toString(bool b)
-{
-    return b ? QLatin1String("true") : QLatin1String("false");
-}
-
 void RemoteFsDevice::saveOptions()
 {
     opts.save(id());
