@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2018-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2018-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -42,9 +42,8 @@ public:
     enum Service {
         LastFm,
         FanArt,
-        Dirble,
         ShoutCast,
-        SoundCloud,
+        //SoundCloud,
 
         NumServices
     };
