@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -33,7 +33,6 @@
 #include "widgets/messageoverlay.h"
 #include "support/icon.h"
 #include "widgets/icons.h"
-#include "config.h"
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QListWidget>
@@ -89,16 +88,6 @@ bool canUse(int w, int h)
     return w>90 && h>90 && (w==h || (h<=(w*1.1) && w<=(h*1.1)));
 }
 
-enum Providers {
-    Prov_LastFm   = 0x0001,
-    Prov_Google   = 0x0002,
-    Prov_CoverArt = 0x0004,
-    Prov_Deezer   = 0x0008,
-    Prov_Spotify  = 0x0010,
-    Prov_ITunes   = 0x0020,
-
-    Prov_All      = 0x003F
-};
 
 class CoverItem : public QListWidgetItem
 {
@@ -184,12 +173,14 @@ public:
         : CoverItem(u, tu, img, QLatin1String("Last.fm"), parent) { }
 };
 
+/*
 class GoogleCover : public CoverItem
 {
 public:
     GoogleCover(const QString &u, const QString &tu, const QImage &img, int w, int h, int size, QListWidget *parent)
         : CoverItem(u, tu, img, QLatin1String("Google"), parent, w, h, size*1024) { }
 };
+*/
 
 class CoverArtArchiveCover : public CoverItem
 {
@@ -205,12 +196,14 @@ public:
         : CoverItem(u, tu, img, QLatin1String("Deezer"), parent)  { }
 };
 
+/*
 class SpotifyCover : public CoverItem
 {
 public:
     SpotifyCover(const QString &u, const QString &tu, const QImage &img, QListWidget *parent)
         : CoverItem(u, tu, img, QLatin1String("Spotify"), parent, 640, 640)  { }
 };
+*/
 
 class ITunesCover : public CoverItem
 {
@@ -308,14 +301,14 @@ void CoverPreview::scaleImage(int adjust)
         return;
     }
     zoom=newZoom;
-    imageLabel->resize(zoom * imageLabel->pixmap()->size());
+    imageLabel->resize(zoom * CANTATA_GET_LABEL_PIXMAP(imageLabel).size());
     setWindowTitle(tr("Image (%1 x %2 %3%)", "Image (width x height zoom%)").arg(imgW).arg(imgH).arg(zoom*100));
 }
 
 void CoverPreview::wheelEvent(QWheelEvent *event)
 {
     if (scrollArea->isVisible() && QApplication::keyboardModifiers() & Qt::ControlModifier) {
-        const int numDegrees = event->delta() / 8;
+        const int numDegrees = event->angleDelta().y() / 8;
         const int numSteps = numDegrees / 15;
         if (0!=numSteps) {
             scaleImage(numSteps);
@@ -329,7 +322,6 @@ void CoverPreview::wheelEvent(QWheelEvent *event)
 CoverDialog::CoverDialog(QWidget *parent)
     : Dialog(parent, "CoverDialog")
     , existing(nullptr)
-    , currentQueryProviders(0)
     , preview(nullptr)
     , saving(false)
     , isArtist(false)
@@ -341,9 +333,6 @@ CoverDialog::CoverDialog(QWidget *parent)
     , showAction(nullptr)
     , removeAction(nullptr)
 {
-    Configuration cfg(objectName());
-    enabledProviders=cfg.get("enabledProviders", (int)Prov_All);
-
     iCount++;
     QWidget *mainWidet = new QWidget(this);
     setupUi(mainWidet);
@@ -386,26 +375,11 @@ CoverDialog::CoverDialog(QWidget *parent)
     addFileButton->setIcon(Icons::self()->folderListIcon);
     addFileButton->setAutoRaise(true);
 
-    configureButton->setIcon(Icons::self()->configureIcon);
-    configureButton->setAutoRaise(true);
-
-    QMenu *configMenu=new QMenu(configureButton);
-    addProvider(configMenu, QLatin1String("Last.fm"), Prov_LastFm, enabledProviders);
-    addProvider(configMenu, tr("CoverArt Archive"), Prov_CoverArt, enabledProviders);
-    addProvider(configMenu, QLatin1String("Google"), Prov_Google, enabledProviders);
-    addProvider(configMenu, QLatin1String("Deezer"), Prov_Deezer, enabledProviders);
-    addProvider(configMenu, QLatin1String("Spotify"), Prov_Spotify, enabledProviders);
-    addProvider(configMenu, QLatin1String("iTunes"), Prov_ITunes, enabledProviders);
-    configureButton->setMenu(configMenu);
-    configureButton->setPopupMode(QToolButton::InstantPopup);
     setAcceptDrops(true);
 }
 
 CoverDialog::~CoverDialog()
 {
-    Configuration cfg(objectName());
-    cfg.set("enabledProviders", enabledProviders);
-
     iCount--;
     cancelQuery();
     clearTempFiles();
@@ -472,9 +446,9 @@ static const char * constHeightProperty="h";
 static const char * constSizeProperty="sz";
 static const char * constTypeProperty="type";
 static const char * constLastFmHost="ws.audioscrobbler.com";
-static const char * constGoogleHost="images.google.com";
+//static const char * constGoogleHost="images.google.com";
 static const char * constCoverArtArchiveHost="coverartarchive.org";
-static const char * constSpotifyHost="ws.spotify.com";
+//static const char * constSpotifyHost="ws.spotify.com";
 static const char * constITunesHost="itunes.apple.com";
 static const char * constDeezerHost="api.deezer.com";
 
@@ -496,12 +470,12 @@ void CoverDialog::queryJobFinished()
         QByteArray resp=reply->readAll();
         if (constLastFmHost==host) {
             parseLastFmQueryResponse(resp);
-        } else if (constGoogleHost==host) {
-            parseGoogleQueryResponse(resp);
+        //} else if (constGoogleHost==host) {
+        //    parseGoogleQueryResponse(resp);
         } else if (constCoverArtArchiveHost==host) {
             parseCoverArtArchiveQueryResponse(resp);
-        } else if (constSpotifyHost==host) {
-            parseSpotifyQueryResponse(resp);
+        //} else if (constSpotifyHost==host) {
+        //    parseSpotifyQueryResponse(resp);
         } else if (constITunesHost==host) {
             parseITunesQueryResponse(resp);
         } else if (constDeezerHost==host) {
@@ -588,13 +562,13 @@ void CoverDialog::downloadJobFinished()
                 img=cropImage(img, isArtist||isComposer);
                 if (constLastFmHost==host) {
                     item=new LastFmCover(reply->property(constLargeProperty).toString(), url, img, list);
-                } else if (constGoogleHost==host) {
-                    item=new GoogleCover(reply->property(constLargeProperty).toString(), url, img, reply->property(constWidthProperty).toInt(),
-                                         reply->property(constHeightProperty).toInt(), reply->property(constSizeProperty).toInt(), list);
+                //} else if (constGoogleHost==host) {
+                //    item=new GoogleCover(reply->property(constLargeProperty).toString(), url, img, reply->property(constWidthProperty).toInt(),
+                //                         reply->property(constHeightProperty).toInt(), reply->property(constSizeProperty).toInt(), list);
                 } else if (constCoverArtArchiveHost==host) {
                     item=new CoverArtArchiveCover(reply->property(constLargeProperty).toString(), url, img, list);
-                } else if (constSpotifyHost==host) {
-                    item=new SpotifyCover(reply->property(constLargeProperty).toString(), url, img, list);
+                //} else if (constSpotifyHost==host) {
+                //    item=new SpotifyCover(reply->property(constLargeProperty).toString(), url, img, list);
                 } else if (constITunesHost==host) {
                     item=new ITunesCover(reply->property(constLargeProperty).toString(), url, img, list);
                 } else if (constDeezerHost==host) {
@@ -660,7 +634,7 @@ void CoverDialog::sendQuery()
         return;
     }
 
-    if (currentQueryString==fixedQuery && enabledProviders==currentQueryProviders) {
+    if (currentQueryString==fixedQuery) {
         page++;
     } else {
         page=0;
@@ -688,24 +662,13 @@ void CoverDialog::sendQuery()
     }
 
     currentQueryString=fixedQuery;
-    if (enabledProviders&Prov_LastFm) {
-        sendLastFmQuery(fixedQuery, page);
-    }
-    if (enabledProviders&Prov_Google) {
-        sendGoogleQuery(fixedQuery, page);
-    }
+    sendLastFmQuery(fixedQuery, page);
+    //sendGoogleQuery(fixedQuery, page);
     if (page==0) {
-        if (enabledProviders&Prov_Spotify) {
-            sendSpotifyQuery(fixedQuery);
-        }
-        if (enabledProviders&Prov_ITunes) {
-            sendITunesQuery(fixedQuery);
-        }
-        if (enabledProviders&Prov_Deezer) {
-            sendDeezerQuery(fixedQuery);
-        }
+        //sendSpotifyQuery(fixedQuery);
+        sendITunesQuery(fixedQuery);
+        sendDeezerQuery(fixedQuery);
     }
-    currentQueryProviders=enabledProviders;
     setSearching(!currentQuery.isEmpty());
 }
 
@@ -725,11 +688,12 @@ void CoverDialog::sendLastFmQuery(const QString &fixedQuery, int page)
     sendQueryRequest(url);
 }
 
+/*
 void CoverDialog::sendGoogleQuery(const QString &fixedQuery, int page)
 {
     QUrl url;
     QUrlQuery query;
-    url.setScheme("http");
+    url.setScheme("https");
     url.setHost(constGoogleHost);
     url.setPath("/images");
     query.addQueryItem("q", fixedQuery);
@@ -739,7 +703,9 @@ void CoverDialog::sendGoogleQuery(const QString &fixedQuery, int page)
     url.setQuery(query);
     sendQueryRequest(url);
 }
+*/
 
+/*
 void CoverDialog::sendSpotifyQuery(const QString &fixedQuery)
 {
     #ifdef QT_NO_SSL
@@ -750,7 +716,7 @@ void CoverDialog::sendSpotifyQuery(const QString &fixedQuery)
     }
     QUrl url;
     QUrlQuery query;
-    url.setScheme("http");
+    url.setScheme("https");
     url.setHost(constSpotifyHost);
     url.setPath(isArtist||isComposer ? "/search/1/artist.json" : "/search/1/album.json");
     query.addQueryItem("q", fixedQuery);
@@ -758,6 +724,7 @@ void CoverDialog::sendSpotifyQuery(const QString &fixedQuery)
     sendQueryRequest(url);
     #endif
 }
+*/
 
 void CoverDialog::sendITunesQuery(const QString &fixedQuery)
 {
@@ -767,7 +734,7 @@ void CoverDialog::sendITunesQuery(const QString &fixedQuery)
 
     QUrl url;
     QUrlQuery query;
-    url.setScheme("http");
+    url.setScheme("https");
     url.setHost(constITunesHost);
     url.setPath("/search");
     query.addQueryItem("term", fixedQuery);
@@ -782,7 +749,7 @@ void CoverDialog::sendDeezerQuery(const QString &fixedQuery)
 {
     QUrl url;
     QUrlQuery query;
-    url.setScheme("http");
+    url.setScheme("https");
     url.setHost(constDeezerHost);
     url.setPath(isArtist||isComposer ? "/search/artist" : "/search/album");
     query.addQueryItem("q", fixedQuery);
@@ -865,27 +832,6 @@ void CoverDialog::removeImages()
     }
 }
 
-void CoverDialog::updateProviders()
-{
-    QAction *s=qobject_cast<QAction *>(sender());
-    enabledProviders=0;
-
-    if (s) {
-        if (Prov_LastFm==s->data().toUInt() && !s->isChecked()) {
-            providers[Prov_CoverArt]->setChecked(false);
-        } else if (Prov_CoverArt==s->data().toUInt() && s->isChecked()) {
-            providers[Prov_LastFm]->setChecked(true);
-        }
-    }
-
-    for (const QAction *act: configureButton->menu()->actions()) {
-        if (act->isChecked()) {
-            enabledProviders|=act->data().toUInt();
-        }
-    }
-    DBUG << enabledProviders;
-}
-
 void CoverDialog::clearTempFiles()
 {
     for (QTemporaryFile *file: tempFiles) {
@@ -1036,17 +982,16 @@ void CoverDialog::parseLastFmQueryResponse(const QByteArray &resp)
         }
     }
 
-    if (enabledProviders&Prov_CoverArt) {
-        for (const QString &id: musicBrainzIds) {
-            QUrl coverartUrl;
-            coverartUrl.setScheme("http");
-            coverartUrl.setHost(constCoverArtArchiveHost);
-            coverartUrl.setPath("/release/"+id);
-            sendQueryRequest(coverartUrl);
-        }
+    for (const QString &id: musicBrainzIds) {
+        QUrl coverartUrl;
+        coverartUrl.setScheme("http");
+        coverartUrl.setHost(constCoverArtArchiveHost);
+        coverartUrl.setPath("/release/"+id);
+        sendQueryRequest(coverartUrl);
     }
 }
 
+/*
 void CoverDialog::parseGoogleQueryResponse(const QByteArray &resp)
 {
     // Code based on Audex CDDA Extractor
@@ -1069,6 +1014,7 @@ void CoverDialog::parseGoogleQueryResponse(const QByteArray &resp)
         pos += rx.matchedLength();
     }
 }
+*/
 
 void CoverDialog::parseCoverArtArchiveQueryResponse(const QByteArray &resp)
 {
@@ -1095,6 +1041,7 @@ void CoverDialog::parseCoverArtArchiveQueryResponse(const QByteArray &resp)
     }
 }
 
+/*
 void CoverDialog::parseSpotifyQueryResponse(const QByteArray &resp)
 {
     QJsonParseError jsonParseError;
@@ -1125,6 +1072,7 @@ void CoverDialog::parseSpotifyQueryResponse(const QByteArray &resp)
         }
     }
 }
+*/
 
 void CoverDialog::parseITunesQueryResponse(const QByteArray &resp)
 {
@@ -1236,13 +1184,13 @@ bool CoverDialog::saveCover(const QString &src, const QImage &img)
         mpdDir=MPDConnection::self()->getDetails().dir;
         if (haveAbsPath || !mpdDir.isEmpty()) {
             dirName=filePath.endsWith('/') ? (haveAbsPath ? QString() : mpdDir)+filePath
-                                            : Utils::getDir((haveAbsPath ? QString() : mpdDir)+filePath);
+                                            : Utils::fixPath((haveAbsPath ? QString() : mpdDir)+song.getDir());
         }
         saveInMpd=QDir(dirName).exists();
     }
 
     if (isArtist) {
-        /*if (saveInMpd && !mpdDir.isEmpty() && dirName.startsWith(mpdDir) && 2==dirName.mid(mpdDir.length()).split('/', QString::SkipEmptyParts).count()) {
+        /*if (saveInMpd && !mpdDir.isEmpty() && dirName.startsWith(mpdDir) && 2==dirName.mid(mpdDir.length()).split('/', CANTATA_SKIP_EMPTY).count()) {
             QDir d(dirName);
             d.cdUp();
             destName=d.absolutePath()+'/'+Covers::constArtistImage+ext;
@@ -1250,7 +1198,7 @@ bool CoverDialog::saveCover(const QString &src, const QImage &img)
             destName=Utils::cacheDir(Covers::constCoverDir, true)+Covers::encodeName(song.albumArtist())+ext;
         }
     } else if (isComposer) {
-        /*if (saveInMpd && !mpdDir.isEmpty() && dirName.startsWith(mpdDir) && 2==dirName.mid(mpdDir.length()).split('/', QString::SkipEmptyParts).count()) {
+        /*if (saveInMpd && !mpdDir.isEmpty() && dirName.startsWith(mpdDir) && 2==dirName.mid(mpdDir.length()).split('/', CANTATA_SKIP_EMPTY).count()) {
             QDir d(dirName);
             d.cdUp();
             destName=d.absolutePath()+'/'+Covers::constComposerImage+ext;
@@ -1338,14 +1286,4 @@ void CoverDialog::setSearching(bool s)
     }
 }
 
-void CoverDialog::addProvider(QMenu *mnu, const QString &name, int bit, int value)
-{
-    QAction *act=mnu->addAction(name);
-    act->setData(bit);
-    act->setCheckable(true);
-    act->setChecked(value&bit);
-    connect(act, SIGNAL(toggled(bool)), this, SLOT(updateProviders()));
-    providers.insert(bit, act);
-}
-
 #include "moc_coverdialog.cpp"
