@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -635,7 +635,7 @@ void CoverDownloader::download(const Song &song)
 
     if (haveAbsPath || !MPDConnection::self()->getDetails().dir.isEmpty()) {
         dirName=fileName.endsWith(Utils::constDirSep) ? (haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+fileName
-                                                      : Utils::getDir((haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+fileName);
+                                                      : Utils::fixPath((haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+song.getDir());
     }
 
     Job job(song, dirName);
@@ -672,7 +672,7 @@ bool CoverDownloader::downloadViaHttp(Job &job, JobType type)
     QString dir=Utils::getDir(job.filePath);
     if (job.song.isArtistImageRequest() || job.song.isComposerImageRequest()) {
         if (job.level) {
-            QStringList parts=dir.split(Utils::constDirSep, QString::SkipEmptyParts);
+            QStringList parts=dir.split(Utils::constDirSep, CANTATA_SKIP_EMPTY);
             if (parts.size()<job.level) {
                 return false;
             }
@@ -1048,7 +1048,7 @@ QString CoverDownloader::saveImg(const Job &job, const QImage &img, const QByteA
         // (As of 2.3.0) No longer save artist images into MPD dir
 //        if (saveInMpdDir && !job.song.isNonMPD() && canSaveTo(job.dir)) {
 //            QString mpdDir=MPDConnection::self()->getDetails().dir;
-//            if (!mpdDir.isEmpty() && job.dir.startsWith(mpdDir) && 2==job.dir.mid(mpdDir.length()).split(Utils::constDirSep, QString::SkipEmptyParts).count()) {
+//            if (!mpdDir.isEmpty() && job.dir.startsWith(mpdDir) && 2==job.dir.mid(mpdDir.length()).split(Utils::constDirSep, CANTATA_SKIP_EMPTY).count()) {
 //                QDir d(job.dir);
 //                d.cdUp();
 //                savedName=save(mimeType, extension, d.absolutePath()+Utils::constDirSep+
@@ -1745,7 +1745,7 @@ Covers::Image Covers::locateImage(const Song &song)
         dirName=song.isCantataStream() ? Utils::getDir(songFile)
                                        : songFile.endsWith(Utils::constDirSep)
                                             ? (haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+songFile
-                                            : Utils::getDir((haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+songFile);
+                                            : Utils::fixPath((haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+song.getDir());
 
         if (song.isArtistImageRequest() || song.isComposerImageRequest()) {
             for (int level=0; level<2; ++level) {
