@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -51,7 +51,7 @@ static void themes(const QString &theme, QStringList &iconThemes)
             while (!f.atEnd()) {
                 QString line=QString::fromUtf8(f.readLine()).trimmed().simplified();
                 if (line.startsWith(key)) {
-                    QStringList inherited=line.mid(key.length()).split(",", QString::SkipEmptyParts);
+                    QStringList inherited=line.mid(key.length()).split(",", CANTATA_SKIP_EMPTY);
                     for (const QString &i: inherited) {
                         themes(i, iconThemes);
                     }
