@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -143,11 +143,6 @@ void LibraryPage::clear()
     view->goToTop();
 }
 
-static inline QString nameKey(const QString &artist, const QString &album)
-{
-    return '{'+artist+"}{"+album+'}';
-}
-
 QStringList LibraryPage::selectedFiles(bool allowPlaylists) const
 {
     QModelIndexList selected = view->selectedIndexes();
