@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -56,7 +56,9 @@
 #include "context/ultimatelyricsprovider.h"
 #include "tags/taghelperiface.h"
 #include "context/contextwidget.h"
+#ifdef ENABLE_SCROBBLING
 #include "scrobbling/scrobbler.h"
+#endif
 #include "gui/mediakeys.h"
 #ifdef ENABLE_HTTP_STREAM_PLAYBACK
 #include "mpd-interface/httpstream.h"
@@ -85,10 +87,10 @@ static void cantataQtMsgHandler(QtMsgType, const QMessageLogContext &, const QSt
         if (f.open(QIODevice::WriteOnly|QIODevice::Append|QIODevice::Text)) {
             QTextStream stream(&f);
             if (firstMsg) {
-                stream << "------------START------------" << endl;
+                stream << "------------START------------" << CANTATA_ENDL;
                 firstMsg=false;
             }
-            stream << QDateTime::currentDateTime().toString(Qt::ISODate).replace("T", " ") << " - " << msg << endl;
+            stream << QDateTime::currentDateTime().toString(Qt::ISODate).replace("T", " ") << " - " << msg << CANTATA_ENDL;
         }
     } else {
         std::cout << QDateTime::currentDateTime().toString(Qt::ISODate).replace("T", " ").toLatin1().constData()
@@ -150,7 +152,9 @@ static QString debugAreas()
             +QObject::tr("song-dialog - Song dialogs (tags, replaygain, organiser)")+QLatin1Char('\n')
             +QObject::tr("network-access - Network access")+QLatin1Char('\n')
             +QObject::tr("threads - Threads")+QLatin1Char('\n')
+            #ifdef ENABLE_SCROBBLING
             +QObject::tr("scrobbler - Scrobbling")+QLatin1Char('\n')
+            #endif
             +QObject::tr("sql - SQL access")+QLatin1Char('\n')
             +QObject::tr("media-keys - Media-keys")+QLatin1Char('\n')
             +QObject::tr("custom-actions - Custom actions")+QLatin1Char('\n')
@@ -172,7 +176,7 @@ static QString debugAreas()
 
 static void installDebugMessageHandler(const QString &cmdLine)
 {
-    QStringList items=cmdLine.split(",", QString::SkipEmptyParts);
+    QStringList items=cmdLine.split(",", CANTATA_SKIP_EMPTY);
 
     for (const auto &area: items) {
         bool all = QLatin1String("all")==area;
@@ -224,9 +228,11 @@ static void installDebugMessageHandler(const QString &cmdLine)
         if (all || QLatin1String("threads")==area) {
             ThreadCleaner::enableDebug();
         }
+        #ifdef ENABLE_SCROBBLING
         if (all || QLatin1String("scrobbler")==area) {
             Scrobbler::enableDebug();
         }
+        #endif
         if (all || QLatin1String("sql")==area) {
             LibraryDb::enableDebug();
         }
@@ -260,13 +266,13 @@ static void installDebugMessageHandler(const QString &cmdLine)
     qInstallMessageHandler(cantataQtMsgHandler);
 }
 
-#if defined Q_OS_LINUX && defined __GNUC__
+#if defined Q_OS_LINUX && defined __GNUC__ && defined __GLIBC__
 #include <execinfo.h>
 #include <unistd.h>
 #include <signal.h>
 #include <cxxabi.h>
 
-static void sigHandler(int i)
+static void sigHandler(int /*i*/)
 {
     // Adapted from: https://panthema.net/2008/0901-stacktrace-demangled/
 
@@ -340,7 +346,7 @@ static void sigHandler(int i)
 
 int main(int argc, char *argv[])
 {
-    #if defined Q_OS_LINUX && defined __GNUC__
+    #if defined Q_OS_LINUX && defined __GNUC__ && defined __GLIBC__
     signal(SIGSEGV, sigHandler);
     #endif
     QThread::currentThread()->setObjectName("GUI");
@@ -414,6 +420,8 @@ int main(int argc, char *argv[])
     loadTranslation("cantata", QDir(local).exists() ? local : CANTATA_SYS_TRANS_DIR, lang);
 
     Application::init();
+    // Ensure QColator gets initialised...
+    Utils::compare(QString(), QString());
 
     if (Settings::self()->firstRun()) {
         InitialSettingsWizard wz;
