@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -72,6 +72,9 @@ class ThumbnailToolBar;
 #ifdef Q_OS_MAC
 class DockMenu;
 #endif
+#ifdef MAC_MEDIAPLAYER_FOUND
+class MacNowPlaying;
+#endif
 
 // Dummy classes so that when class name is saved to the config file, we get a more meaningful name than QWidget!!!
 class PlayQueuePage : public QWidget
@@ -139,8 +142,12 @@ Q_SIGNALS:
     void setSeekId(qint32, quint32);
     void startPlayingSongId(qint32);
     void setVolume(int);
+    void changePartition(QString partition);
+    void newPartition(QString name);
+    void delPartition(QString name);
     void outputs();
     void enableOutput(quint32 id, bool);
+    void moveOutput(QString name);
     void setPriority(const QList<qint32> &ids, quint8 priority, bool decreasePriority);
     void addSongsToPlaylist(const QString &name, const QStringList &files);
     void showPreferencesPage(const QString &page);
@@ -163,6 +170,10 @@ public Q_SLOTS:
     void commitDataRequest(QSessionManager &mgr);
     void updateSettings();
     void toggleOutput();
+    void moveOutputToThisPartition();
+    void selectPartition();
+    void createNewPartition();
+    void deleteAPartition();
     void changeConnection();
     void connectToMpd();
     void connectToMpd(const MPDConnectionDetails &details);
@@ -237,6 +248,7 @@ public Q_SLOTS:
     void expandAll();
     void collapseAll();
     void checkMpdDir();
+    void partitionsUpdated(const QList<Partition> &outputs);
     void outputsUpdated(const QList<Output> &outputs);
     void updateConnectionsMenu();
     void controlConnectionsMenu(bool enable=true);
@@ -274,6 +286,7 @@ private:
     int prevPage;
     MPDState lastState;
     qint32 lastSongId;
+    QString lastPartition;
     PlayQueueProxyModel playQueueProxyModel;
     bool autoScrollPlayQueue;
     bool singlePane;
@@ -283,8 +296,10 @@ private:
     Action *doDbRefreshAction;
     Action *connectAction;
     Action *connectionsAction;
+    Action *partitionsAction;
     Action *outputsAction;
     QActionGroup *connectionsGroup;
+    QActionGroup *partitionsGroup;
     Action *stopAfterTrackAction;
     Action *addPlayQueueToStoredPlaylistAction;
     Action *clearPlayQueueAction;
@@ -364,6 +379,9 @@ private:
     #ifdef Q_OS_MAC
     DockMenu *dockMenu;
     #endif
+    #ifdef MAC_MEDIAPLAYER_FOUND
+    MacNowPlaying *macNowPlaying;
+    #endif
     friend class TrayItem;
 };
 
