@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -70,8 +70,6 @@ class CollectionNameValidator : public QValidator
 ServerSettings::ServerSettings(QWidget *p)
     : QWidget(p)
     , haveBasicCollection(false)
-    , isCurrentConnection(false)
-    , allOptions(true) // will be toggled
     , prevIndex(0)
 {
     setupUi(this);
