@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -166,6 +166,7 @@ MPDConnectionDetails Settings::connectionDetails(const QString &name)
         details.port=grp.get("port", name.isEmpty() ? mpdDefaults.port : 6600);
         details.dir=grp.getDirPath("dir", name.isEmpty() ? mpdDefaults.dir : "/var/lib/mpd/music");
         details.password=grp.get("passwd", name.isEmpty() ? mpdDefaults.passwd : QString());
+        details.partition=grp.get("partition", QString());
         #ifdef ENABLE_HTTP_STREAM_PLAYBACK
         details.streamUrl=grp.get("streamUrl", QString());
         #endif
@@ -246,6 +247,11 @@ QSize Settings::mainWindowCollapsedSize()
     return cfg.get("mainWindowCollapsedSize", QSize());
 }
 
+QPoint Settings::mainWindowPos()
+{
+    return cfg.get("mainWindowPos", QPoint());
+}
+
 bool Settings::maximized()
 {
     return cfg.get("maximized", false);
@@ -314,17 +320,17 @@ int Settings::sidebar()
 
 QSet<QString> Settings::composerGenres()
 {
-    return cfg.get("composerGenres", Song::composerGenres().toList()).toSet();
+    return Utils::listToSet(cfg.get("composerGenres", Song::composerGenres().values()));
 }
 
 QSet<QString> Settings::singleTracksFolders()
 {
-    return cfg.get("singleTracksFolders", QStringList()).toSet();
+    return Utils::listToSet(cfg.get("singleTracksFolders", QStringList()));
 }
 
 MPDParseUtils::CueSupport Settings::cueSupport()
 {
-    return MPDParseUtils::toCueSupport(cfg.get("cueSupport", MPDParseUtils::toStr(MPDParseUtils::Cue_Parse)));
+    return MPDParseUtils::toCueSupport(cfg.get("cueSupport", MPDParseUtils::toStr(MPDParseUtils::Cue_Ignore)));
 }
 
 QStringList Settings::lyricProviders()
@@ -672,7 +678,7 @@ bool Settings::infoTooltips()
 
 QSet<QString> Settings::ignorePrefixes()
 {
-    return cfg.get("ignorePrefixes", Song::ignorePrefixes().toList()).toSet();
+    return Utils::listToSet(cfg.get("ignorePrefixes", Song::ignorePrefixes().values()));
 }
 
 bool Settings::mpris()
@@ -729,6 +735,7 @@ void Settings::saveConnectionDetails(const MPDConnectionDetails &v)
         grp.setDirPath("dir", v.dir);
     }
     grp.set("passwd", v.password);
+    grp.set("partition", v.partition);
     #ifdef ENABLE_HTTP_STREAM_PLAYBACK
     grp.set("streamUrl", v.streamUrl);
     #endif
@@ -784,6 +791,11 @@ void Settings::saveMainWindowCollapsedSize(const QSize &v)
     }
 }
 
+void Settings::saveMainWindowPos(const QPoint &pos)
+{
+    return cfg.set("mainWindowPos", pos);
+}
+
 void Settings::saveUseSystemTray(bool v)
 {
     cfg.set("useSystemTray", v);
@@ -826,12 +838,12 @@ void Settings::saveSidebar(int v)
 
 void Settings::saveComposerGenres(const QSet<QString> &v)
 {
-    cfg.set("composerGenres", v.toList());
+    cfg.set("composerGenres", v.values());
 }
 
 void Settings::saveSingleTracksFolders(const QSet<QString> &v)
 {
-    cfg.set("singleTracksFolders", v.toList());
+    cfg.set("singleTracksFolders", v.values());
 }
 
 void Settings::saveCueSupport(MPDParseUtils::CueSupport v)
@@ -1161,7 +1173,7 @@ void Settings::saveInfoTooltips(bool v)
 
 void Settings::saveIgnorePrefixes(const QSet<QString> &v)
 {
-    cfg.set("ignorePrefixes", v.toList());
+    cfg.set("ignorePrefixes", v.values());
 }
 
 void Settings::saveMpris(bool v)
