@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -49,7 +49,7 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event) override
     {
         if (QEvent::Wheel==event->type()) {
-            int numDegrees = static_cast<QWheelEvent *>(event)->delta() / 8;
+            int numDegrees = static_cast<QWheelEvent *>(event)->angleDelta().y() / 8;
             int numSteps = numDegrees / 15;
             if (numSteps > 0) {
                 for (int i = 0; i < numSteps; ++i) {
@@ -78,6 +78,7 @@ TrayItem::TrayItem(MainWindow *p)
     , notification(nullptr)
     #endif
     , connectionsAction(nullptr)
+    , partitionsAction(nullptr)
     , outputsAction(nullptr)
     #endif
 {
@@ -131,9 +132,12 @@ void TrayItem::setup()
     #ifndef Q_OS_MAC
     connectionsAction=new Action(Utils::strippedText(mw->connectionsAction->text()), this);
     connectionsAction->setVisible(false);
+    partitionsAction=new Action(Utils::strippedText(mw->partitionsAction->text()), this);
+    partitionsAction->setVisible(false);
     outputsAction=new Action(Utils::strippedText(mw->outputsAction->text()), this);
     outputsAction->setVisible(false);
     updateConnections();
+    updatePartitions();
     updateOutputs();
     #endif
 
@@ -155,6 +159,7 @@ void TrayItem::setup()
     #ifndef Q_OS_MAC
     trayItemMenu->addSeparator();
     trayItemMenu->addAction(connectionsAction);
+    trayItemMenu->addAction(partitionsAction);
     trayItemMenu->addAction(outputsAction);
     #endif
     trayItemMenu->addSeparator();
@@ -276,6 +281,13 @@ void TrayItem::updateConnections()
     #endif
 }
 
+void TrayItem::updatePartitions()
+{
+    #ifndef Q_OS_MAC
+    copyMenu(mw->partitionsAction, partitionsAction);
+    #endif
+}
+
 void TrayItem::updateOutputs()
 {
     #ifndef Q_OS_MAC
