@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2017-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2017-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -320,7 +320,7 @@ void BrowseModel::folderContents(const QString &path, const QStringList &folders
 
 		beginInsertRows(idx, 0, folders.count() + songs.count() - 1);
         for (const QString &folder: folders) {
-			FolderItem *item = new FolderItem(folder.split("/", QString::SkipEmptyParts).last(), folder, it.value());
+			FolderItem *item = new FolderItem(folder.split("/", CANTATA_SKIP_EMPTY).last(), folder, it.value());
 			it.value()->add(item);
 			folderIndex.insert(folder, item);
 		}
