@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -443,7 +443,7 @@ bool MusicLibraryItemRoot::fromXML(QXmlStreamReader &reader, const QString &base
                     song.setAlbumArtistSort(attributes.value(constAlbumArtistSortAttribute).toString());
                 }
                 if (attributes.hasAttribute(constGenreAttribute)) {
-                    QStringList genres=attributes.value(constGenreAttribute).toString().split(",", QString::SkipEmptyParts);
+                    QStringList genres=attributes.value(constGenreAttribute).toString().split(",", CANTATA_SKIP_EMPTY);
                     for (int i=0; i<Song::constNumGenres && i<genres.count(); ++i) {
                         song.addGenre(genres[i]);
                     }
