@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -61,6 +61,7 @@ QString PlaylistsModel::headerText(int col)
     case COL_GENRE:     return PlayQueueModel::headerText(PlayQueueModel::COL_GENRE);
     case COL_COMPOSER:  return PlayQueueModel::headerText(PlayQueueModel::COL_COMPOSER);
     case COL_PERFORMER: return PlayQueueModel::headerText(PlayQueueModel::COL_PERFORMER);
+    case COL_GROUPING:  return PlayQueueModel::headerText(PlayQueueModel::COL_GROUPING);
     case COL_FILENAME:  return PlayQueueModel::headerText(PlayQueueModel::COL_FILENAME);
     case COL_PATH:      return PlayQueueModel::headerText(PlayQueueModel::COL_PATH);
     default:            return QString();
@@ -95,7 +96,7 @@ PlaylistsModel::PlaylistsModel(QObject *parent)
     connect(newAction, SIGNAL(triggered()), this, SIGNAL(addToNew()));
     Action::initIcon(newAction);
     alignments[COL_TITLE]=alignments[COL_ARTIST]=alignments[COL_ALBUM]=alignments[COL_GENRE]=alignments[COL_COMPOSER]=
-            alignments[COL_PERFORMER]=alignments[COL_FILENAME]=alignments[COL_PATH]=int(Qt::AlignVCenter|Qt::AlignLeft);
+            alignments[COL_PERFORMER]=alignments[COL_FILENAME]=alignments[COL_PATH]=alignments[COL_GROUPING]=int(Qt::AlignVCenter|Qt::AlignLeft);
     alignments[COL_LENGTH]=alignments[COL_YEAR]=alignments[COL_ORIGYEAR]=int(Qt::AlignVCenter|Qt::AlignRight);
 }
 
@@ -216,7 +217,7 @@ QVariant PlaylistsModel::headerData(int section, Qt::Orientation orientation, in
             return alignments[section];
         case Cantata::Role_InitiallyHidden:
             return COL_YEAR==section || COL_ORIGYEAR==section || COL_GENRE==section || COL_COMPOSER==section || COL_PERFORMER==section ||
-                   COL_FILENAME==section || COL_PATH==section;
+                   COL_FILENAME==section || COL_PATH==section || COL_GROUPING==section;
         case Cantata::Role_Hideable:
             return COL_LENGTH!=section;
         case Cantata::Role_Width:
@@ -230,6 +231,7 @@ QVariant PlaylistsModel::headerData(int section, Qt::Orientation orientation, in
             case COL_LENGTH:    return 0.125;
             case COL_COMPOSER:  return 0.15;
             case COL_PERFORMER: return 0.15;
+            case COL_GROUPING:  return 0.15;
             case COL_FILENAME:  return 0.15;
             case COL_PATH:      return 0.15;
             }
@@ -456,6 +458,8 @@ QVariant PlaylistsModel::data(const QModelIndex &index, int role) const
                     return s->composer();
                 case COL_PERFORMER:
                     return s->performer();
+                case COL_GROUPING:
+                    return s->grouping();
                 case COL_FILENAME:
                     return Utils::getFile(QUrl(s->file).path());
                 case COL_PATH: {
