@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -27,6 +27,7 @@
 #define PLAYLISTSPROXYMODEL_H
 
 #include "proxymodel.h"
+#include "support/utils.h"
 
 class PlaylistsProxyModel : public ProxyModel
 {
@@ -35,7 +36,7 @@ class PlaylistsProxyModel : public ProxyModel
 public:
     PlaylistsProxyModel(QObject *parent = nullptr);
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
-    static bool compareNames(const QString &l, const QString &r) { return l.localeAwareCompare(r)<0; }
+    static bool compareNames(const QString &l, const QString &r) { return Utils::compare(l, r)<0; }
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 };
 
