@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -82,6 +82,8 @@ static const QLatin1String constSortByComposerKey("composer");
 static const QLatin1String constSortByPerformerKey("performer");
 static const QLatin1String constSortByTitleKey("title");
 static const QLatin1String constSortByNumberKey("track");
+static const QLatin1String constSortByPathKey("path");
+static const QLatin1String constSortByGrouping("grouping");
 
 static QSet<QString> constM3uPlaylists = QSet<QString>() << QLatin1String("m3u") << QLatin1String("m3u8");
 static const QString constPlsPlaylist = QLatin1String("pls");
@@ -324,7 +326,7 @@ void PlayQueueModel::encode(QMimeData &mimeData, const QString &mime, const QStr
     QTextStream stream(&encodedData, QIODevice::WriteOnly);
 
     for (const QString &v: values) {
-        stream << v << endl;
+        stream << v << CANTATA_ENDL;
     }
 
     mimeData.setData(mime, encodedData);
@@ -381,6 +383,7 @@ QString PlayQueueModel::headerText(int col)
     case COL_PRIO:      return tr("Priority");
     case COL_COMPOSER:  return tr("Composer");
     case COL_PERFORMER: return tr("Performer");
+    case COL_GROUPING:  return tr("Grouping");
     case COL_RATING:    return tr("Rating");
     case COL_FILENAME:  return tr("Filename");
     case COL_PATH:      return tr("Path");
@@ -388,6 +391,12 @@ QString PlayQueueModel::headerText(int col)
     }
 }
 
+static bool simpleSort = false;
+void PlayQueueModel::setSimpleSort(bool simple)
+{
+    simpleSort = simple;
+}
+
 PlayQueueModel::PlayQueueModel(QObject *parent)
     : QAbstractItemModel(parent)
     , currentSongId(-1)
@@ -459,11 +468,13 @@ PlayQueueModel::PlayQueueModel(QObject *parent)
     addSortAction(tr("Year"), constSortByYearKey);
     addSortAction(tr("Composer"), constSortByComposerKey);
     addSortAction(tr("Performer"), constSortByPerformerKey);
+    addSortAction(tr("Path"), constSortByPathKey);
+    addSortAction(tr("Grouping"), constSortByGrouping);
     controlActions();
     shuffleAction->setEnabled(false);
     sortAction->setEnabled(false);
     alignments[COL_TITLE]=alignments[COL_ARTIST]=alignments[COL_ALBUM]=alignments[COL_GENRE]=alignments[COL_COMPOSER]=
-            alignments[COL_PERFORMER]=alignments[COL_FILENAME]=alignments[COL_PATH]=int(Qt::AlignVCenter|Qt::AlignLeft);
+            alignments[COL_PERFORMER]=alignments[COL_FILENAME]=alignments[COL_PATH]=alignments[COL_GROUPING]=int(Qt::AlignVCenter|Qt::AlignLeft);
     alignments[COL_TRACK]=alignments[COL_LENGTH]=alignments[COL_DISC]=alignments[COL_YEAR]=alignments[COL_ORIGYEAR]=
             alignments[COL_PRIO]=int(Qt::AlignVCenter|Qt::AlignRight);
     alignments[COL_RATING]=int(Qt::AlignVCenter|Qt::AlignHCenter);
@@ -494,7 +505,7 @@ QVariant PlayQueueModel::headerData(int section, Qt::Orientation orientation, in
             return alignments[section];
         case Cantata::Role_InitiallyHidden:
             return COL_YEAR==section || COL_ORIGYEAR==section || COL_DISC==section || COL_GENRE==section || COL_PRIO==section ||
-                   COL_COMPOSER==section || COL_PERFORMER==section || COL_RATING==section || COL_FILENAME==section || COL_PATH==section;
+                   COL_COMPOSER==section || COL_PERFORMER==section || COL_RATING==section || COL_FILENAME==section || COL_PATH==section || COL_GROUPING==section;
         case Cantata::Role_Hideable:
             return COL_LENGTH!=section;
         case Cantata::Role_Width:
@@ -511,10 +522,12 @@ QVariant PlayQueueModel::headerData(int section, Qt::Orientation orientation, in
             case COL_PRIO:      return 0.015;
             case COL_COMPOSER:  return 0.2;
             case COL_PERFORMER: return 0.2;
+            case COL_GROUPING:  return 0.2;
             case COL_RATING:    return 0.08;
             case COL_FILENAME:  return 0.27;
             case COL_PATH:      return 0.27;
             }
+            break;
         case Cantata::Role_ContextMenuText:
             return COL_TRACK==section ? tr("# (Track Number)") : headerText(section);
         default:
@@ -746,6 +759,8 @@ QVariant PlayQueueModel::data(const QModelIndex &index, int role) const
             return song.composer();
         case COL_PERFORMER:
             return song.performer();
+        case  COL_GROUPING:
+            return song.grouping();
 //        case COL_RATING:{
 //            QVariant var;
 //            const Song &s=songs.at(index.row());
@@ -1160,6 +1175,7 @@ void PlayQueueModel::update(const QList<Song> &songList, bool isComplete)
                     Song old=songs.takeAt(existingPos);
 //                     old.pos=s.pos;
                     s.rating=old.rating;
+                    s.time=old.time;
                     songs.insert(i, isEmpty ? old : s);
                     endMoveRows();
                 }
@@ -1268,7 +1284,7 @@ void PlayQueueModel::crop(const QList<int> &rowsToKeep)
 
     QSet<qint32> removeIds=allIds-keepIds;
     if (!removeIds.isEmpty()) {
-        emit removeSongs(removeIds.toList());
+        emit removeSongs(removeIds.values());
     }
 }
 
@@ -1283,7 +1299,7 @@ void PlayQueueModel::setRating(const QList<int> &rows, quint8 rating) const
             }
         }
     }
-    emit setRating(files.toList(), rating);
+    emit setRating(files.values(), rating);
 }
 
 void PlayQueueModel::enableUndo(bool e)
@@ -1395,27 +1411,40 @@ void PlayQueueModel::addSortAction(const QString &name, const QString &key)
     connect(action, SIGNAL(triggered()), SLOT(sortBy()));
 }
 
+static bool otherSort(const Song *s1, const Song *s2, quint32 other)
+{
+    const QString v1=s1->hasExtraField(other) ? s1->extraField(other) : QString();
+    const QString v2=s2->hasExtraField(other) ? s2->extraField(other) : QString();
+    int c=Utils::compare(v1, v2);
+    if (simpleSort) {
+        return c<0;
+    }
+    return c<0 || (c==0 && (*s1)<(*s2));
+}
+
 static bool composerSort(const Song *s1, const Song *s2)
 {
-    const QString v1=s1->hasComposer() ? s1->composer() : QString();
-    const QString v2=s2->hasComposer() ? s2->composer() : QString();
-    int c=v1.localeAwareCompare(v2);
-    return c<0 || (c==0 && (*s1)<(*s2));
+    return otherSort(s1, s2, Song::Composer);
 }
 
 static bool performerSort(const Song *s1, const Song *s2)
 {
-    const QString v1=s1->hasPerformer() ? s1->performer() : QString();
-    const QString v2=s2->hasPerformer() ? s2->performer() : QString();
-    int c=v1.localeAwareCompare(v2);
-    return c<0 || (c==0 && (*s1)<(*s2));
+    return otherSort(s1, s2, Song::Performer);
+}
+
+static bool groupingSort(const Song *s1, const Song *s2)
+{
+    return otherSort(s1, s2, Song::Grouping);
 }
 
 static bool artistSort(const Song *s1, const Song *s2)
 {
     const QString v1=s1->hasArtistSort() ? s1->artistSort() : s1->artist;
     const QString v2=s2->hasArtistSort() ? s2->artistSort() : s2->artist;
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
+    if (simpleSort) {
+        return c<0;
+    }
     return c<0 || (c==0 && (*s1)<(*s2));
 }
 
@@ -1423,7 +1452,10 @@ static bool albumArtistSort(const Song *s1, const Song *s2)
 {
     const QString v1=s1->hasAlbumArtistSort() ? s1->albumArtistSort() : s1->albumArtistOrComposer();
     const QString v2=s2->hasAlbumArtistSort() ? s2->albumArtistSort() : s2->albumArtistOrComposer();
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
+    if (simpleSort) {
+        return c<0;
+    }
     return c<0 || (c==0 && (*s1)<(*s2));
 }
 
@@ -1431,30 +1463,56 @@ static bool albumSort(const Song *s1, const Song *s2)
 {
     const QString v1=s1->hasAlbumSort() ? s1->albumSort() : s1->album;
     const QString v2=s2->hasAlbumSort() ? s2->albumSort() : s2->album;
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
+    if (simpleSort) {
+        return c<0;
+    }
     return c<0 || (c==0 && (*s1)<(*s2));
 }
 
 static bool genreSort(const Song *s1, const Song *s2)
 {
     int c=s1->compareGenres(*s2);
+    if (simpleSort) {
+        return c<0;
+    }
     return c<0 || (c==0 && (*s1)<(*s2));
 }
 
 static bool yearSort(const Song *s1, const Song *s2)
 {
-    return s1->year<s2->year || (s1->year==s2->year && (*s1)<(*s2));
+    bool c = s1->year<s2->year;
+    if (simpleSort) {
+        return c;
+    }
+    return c || (s1->year==s2->year && (*s1)<(*s2));
 }
 
 static bool titleSort(const Song *s1, const Song *s2)
 {
-    int c=s1->title.localeAwareCompare(s2->title);
+    int c=Utils::compare(s1->title, s2->title);
+    if (simpleSort) {
+        return c<0;
+    }
     return c<0 || (c==0 && (*s1)<(*s2));
 }
 
 static bool trackSort(const Song *s1, const Song *s2)
 {
-    return s1->track<s2->track || (s1->track==s2->track && (*s1)<(*s2));
+    bool c = s1->track<s2->track;
+    if (simpleSort) {
+        return c;
+    }
+    return c || (s1->track==s2->track && (*s1)<(*s2));
+}
+
+static bool pathSort(const Song *s1, const Song *s2)
+{
+    int c=Utils::compare(s1->file, s2->file);
+    if (simpleSort) {
+        return c<0;
+    }
+    return c<0 || (c==0 && (*s1)<(*s2));
 }
 
 void PlayQueueModel::sortBy()
@@ -1469,24 +1527,29 @@ void PlayQueueModel::sortBy()
         }
 
         if (constSortByArtistKey==key) {
-            std::sort(copy.begin(), copy.end(), artistSort);
+            std::stable_sort(copy.begin(), copy.end(), artistSort);
         } else if (constSortByAlbumArtistKey==key) {
-            std::sort(copy.begin(), copy.end(), albumArtistSort);
+            std::stable_sort(copy.begin(), copy.end(), albumArtistSort);
         } else if (constSortByAlbumKey==key) {
-            std::sort(copy.begin(), copy.end(), albumSort);
+            std::stable_sort(copy.begin(), copy.end(), albumSort);
         } else if (constSortByGenreKey==key) {
-            std::sort(copy.begin(), copy.end(), genreSort);
+            std::stable_sort(copy.begin(), copy.end(), genreSort);
         } else if (constSortByYearKey==key) {
-            std::sort(copy.begin(), copy.end(), yearSort);
+            std::stable_sort(copy.begin(), copy.end(), yearSort);
         } else if (constSortByComposerKey==key) {
-            std::sort(copy.begin(), copy.end(), composerSort);
+            std::stable_sort(copy.begin(), copy.end(), composerSort);
         } else if (constSortByPerformerKey==key) {
-            std::sort(copy.begin(), copy.end(), performerSort);
+            std::stable_sort(copy.begin(), copy.end(), performerSort);
         } else if (constSortByTitleKey==key) {
-            std::sort(copy.begin(), copy.end(), titleSort);
+            std::stable_sort(copy.begin(), copy.end(), titleSort);
         } else if (constSortByNumberKey==key) {
-            std::sort(copy.begin(), copy.end(), trackSort);
+            std::stable_sort(copy.begin(), copy.end(), trackSort);
+        } else if (constSortByPathKey==key) {
+            std::stable_sort(copy.begin(), copy.end(), pathSort);
+        } else if (constSortByGrouping==key) {
+            std::stable_sort(copy.begin(), copy.end(), groupingSort);
         }
+
         QList<quint32> positions;
         for (const Song *s: copy) {
             positions.append(getRowById(s->id));
