@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -60,6 +60,7 @@ public:
         COL_PRIO,
         COL_COMPOSER,
         COL_PERFORMER,
+        COL_GROUPING,
         COL_RATING,
         COL_FILENAME,
         COL_PATH,
@@ -85,6 +86,7 @@ public:
     static QStringList decode(const QMimeData &mimeData, const QString &mime);
     static QList<quint32> decodeInts(const QMimeData &mimeData, const QString &mime);
     static QString headerText(int col);
+    static void setSimpleSort(bool simple);
 
     static PlayQueueModel * self();
 
