@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2017-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2017-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -26,6 +26,7 @@
 #include "gui/settings.h"
 #include "widgets/icons.h"
 #include "support/configuration.h"
+#include "support/utils.h"
 #include "roles.h"
 #include <QMimeData>
 #include <time.h>
@@ -482,7 +483,7 @@ static bool containsParent(const QSet<QModelIndex> &set, const QModelIndex &idx)
 QList<Song> SqlLibraryModel::songs(const QModelIndexList &list, bool allowPlaylists) const
 {
     QList<Song> songList;
-    QSet<QModelIndex> set=list.toSet();
+    QSet<QModelIndex> set=Utils::listToSet(list);
     populate(list);
     for (const QModelIndex &idx: list) {
         if (!containsParent(set, idx)) {
@@ -595,9 +596,9 @@ QSet<QString> SqlLibraryModel::getArtists() const
     return db->get("albumArtist");
 }
 
-QList<Song> SqlLibraryModel::getAlbumTracks(const QString &artistId, const QString &albumId) const
+QList<Song> SqlLibraryModel::getAlbumTracks(const QString &artistId, const QString &albumId, int maxTracks) const
 {
-    return db->getTracks(artistId, albumId, QString(), LibraryDb::AS_ArAlYr, false);
+    return db->getTracks(artistId, albumId, QString(), LibraryDb::AS_ArAlYr, false, maxTracks);
 }
 
 QList<Song> SqlLibraryModel::songs(const QStringList &files, bool allowPlaylists) const
