@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -154,7 +154,7 @@ void HttpStream::streamUrl(const QString &url)
     #else
     if (player) {
         QMediaContent media = player->media();
-        if (media != nullptr && media.canonicalUrl() != url) {
+        if (media != nullptr && media.request().url() != url) {
             player->stop();
             player->deleteLater();
             player = nullptr;
@@ -226,13 +226,13 @@ void HttpStream::updateStatus()
     case MPDState_Playing:
         // Only start playback if not aready playing
         if (playerNeedsToStart) {
-        #ifdef LIBVLC_FOUND
+            #ifdef LIBVLC_FOUND
             libvlc_media_player_play(player);
             startTimer();
-        #else
-            QUrl url = player->media().canonicalUrl();
+            #else
+            QUrl url = player->media().request().url();
             player->setMedia(url);
-        #endif
+            #endif
         }
         break;
     case MPDState_Paused:
