@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -37,6 +37,7 @@
 #include <QTimer>
 #include <QDir>
 #include <QHostInfo>
+#include <QDate>
 #include <QDateTime>
 #include <QPropertyAnimation>
 #include <QCoreApplication>
@@ -48,6 +49,8 @@
 #include "dbus/powermanagement.h"
 #elif defined Q_OS_MAC && defined IOKIT_FOUND
 #include "mac/powermanagement.h"
+#elif defined Q_OS_WIN
+#define sscanf sscanf_s
 #endif
 #include <algorithm>
 #include <QDebug>
@@ -79,6 +82,7 @@ static const QByteArray constIdlePlayerValue("player");
 static const QByteArray constIdleMixerValue("mixer");
 static const QByteArray constIdleOptionsValue("options");
 static const QByteArray constIdleOutputValue("output");
+static const QByteArray constIdlePartitionValue("partition");
 static const QByteArray constIdleStickerValue("sticker");
 static const QByteArray constIdleSubscriptionValue("subscription");
 static const QByteArray constIdleMessageValue("message");
@@ -228,6 +232,7 @@ MPDConnectionDetails & MPDConnectionDetails::operator=(const MPDConnectionDetail
     hostname=o.hostname;
     port=o.port;
     password=o.password;
+    partition=o.partition;
     dir=o.dir;
     dirReadable=o.dirReadable;
     #ifdef ENABLE_HTTP_STREAM_PLAYBACK
@@ -269,9 +274,11 @@ MPDConnection::MPDConnection()
 {
     qRegisterMetaType<time_t>("time_t");
     qRegisterMetaType<Song>("Song");
+    qRegisterMetaType<Partition>("Partition");
     qRegisterMetaType<Output>("Output");
     qRegisterMetaType<Playlist>("Playlist");
     qRegisterMetaType<QList<Song> >("QList<Song>");
+    qRegisterMetaType<QList<Partition> >("QList<Partition>");
     qRegisterMetaType<QList<Output> >("QList<Output>");
     qRegisterMetaType<QList<Playlist> >("QList<Playlist>");
     qRegisterMetaType<QList<quint32> >("QList<quint32>");
@@ -289,7 +296,7 @@ MPDConnection::MPDConnection()
     #if (defined Q_OS_LINUX && defined QT_QTDBUS_FOUND) || (defined Q_OS_MAC && defined IOKIT_FOUND)
     connect(PowerManagement::self(), SIGNAL(resuming()), this, SLOT(reconnect()));
     #endif
-    MPDParseUtils::setSingleTracksFolders(Configuration().get("singleTracksFolders", QStringList()).toSet());
+    MPDParseUtils::setSingleTracksFolders(Utils::listToSet(Configuration().get("singleTracksFolders", QStringList())));
 }
 
 MPDConnection::~MPDConnection()
@@ -389,6 +396,15 @@ MPDConnection::ConnectionReturn MPDConnection::connectToMPD(MpdSocket &socket, b
                 }
             }
 
+            if (!details.partition.isEmpty()) {
+                DBUG << (void *)(&socket) << "setting partition...";
+                socket.write("partition "+encodeName(details.partition)+'\n');
+                socket.waitForBytesWritten(constSocketCommsTimeout);
+                if (!readReply(socket).ok) {
+                    DBUG << (void *)(&socket) << "partition rejected, staying on default";
+                }
+            }
+
             if (enableIdle) {
                 dynamicId.clear();
                 setupRemoteDynamic();
@@ -518,11 +534,13 @@ void MPDConnection::reconnect()
     time_t now=time(nullptr);
     ConnectionReturn status=connectToMPD();
     switch (status) {
-    case Success:        
+    case Success:
         // Issue #1041 - MPD does not seem to persist user/client made replaygain changes, so use the values read from Cantata's config.
         if (replaygainSupported() && details.applyReplayGain && !details.replayGain.isEmpty()) {
             sendCommand("replay_gain_mode "+details.replayGain.toLatin1());
         }
+        serverInfo.detect();
+        listPartitions();
         getStatus();
         getStats();
         getUrlHandlers();
@@ -616,6 +634,7 @@ void MPDConnection::setDetails(const MPDConnectionDetails &d)
                 sendCommand("replay_gain_mode "+details.replayGain.toLatin1());
             }
             serverInfo.detect();
+            listPartitions();
             getStatus();
             getStats();
             getUrlHandlers();
@@ -680,6 +699,7 @@ MPDConnection::Response MPDConnection::sendCommand(const QByteArray &command, bo
         } else {
             // Refresh playqueue...
             reconnected=true;
+            listPartitions();
             playListInfo();
             getStatus();
             reconnected=false;
@@ -1089,6 +1109,9 @@ void MPDConnection::playListChanges()
     Response response=sendCommand(data, false);
     if (response.ok && status.ok && isPlayQueueIdValid()) {
         MPDStatusValues sv=MPDParseUtils::parseStatus(status.data);
+        if (lastUpdatePlayQueueVersion==sv.playlist) {
+            return; // Playlist is already up-to-date
+        }
         lastUpdatePlayQueueVersion=lastStatusPlayQueueVersion=sv.playlist;
         emitStatusUpdated(sv);
         QList<MPDParseUtils::IdPos> changes=MPDParseUtils::parseChanges(response.data);
@@ -1102,7 +1125,7 @@ void MPDConnection::playListChanges()
             QList<Song> songs;
             QList<Song> newCantataStreams;
             QList<qint32> ids;
-            QSet<qint32> prevIds=playQueueIds.toSet();
+            QSet<qint32> prevIds=Utils::listToSet(playQueueIds);
             QSet<qint32> strmIds;
 
             for (const MPDParseUtils::IdPos &idp: changes) {
@@ -1176,7 +1199,7 @@ void MPDConnection::playListChanges()
             if (!newCantataStreams.isEmpty()) {
                 emit cantataStreams(newCantataStreams, true);
             }
-            QSet<qint32> removed=prevIds-playQueueIds.toSet();
+            QSet<qint32> removed=prevIds-Utils::listToSet(playQueueIds);
             if (!removed.isEmpty()) {
                 emit removedIds(removed);
             }
@@ -1248,7 +1271,7 @@ void MPDConnection::setReplayGain(const QString &v)
 void MPDConnection::getReplayGain()
 {
     if (replaygainSupported()) {
-        QStringList lines=QString(sendCommand("replay_gain_status").data).split('\n', QString::SkipEmptyParts);
+        QStringList lines=QString(sendCommand("replay_gain_status").data).split('\n', CANTATA_SKIP_EMPTY);
 
         if (2==lines.count() && "OK"==lines[1] && lines[0].startsWith(QLatin1String("replay_gain_mode: "))) {
             QString mode=lines[0].mid(18);
@@ -1471,6 +1494,12 @@ void MPDConnection::getStatus()
     if (response.ok) {
         MPDStatusValues sv=MPDParseUtils::parseStatus(response.data);
         lastStatusPlayQueueVersion=sv.playlist;
+        if (details.partition != sv.partition) {
+            details.partition = sv.partition;
+            Settings::self()->saveConnectionDetails(details);
+            lastUpdatePlayQueueVersion=0;
+            playQueueIds.clear();
+        }
         if (currentSongId!=sv.songId) {
             stopVolumeFade();
         }
@@ -1492,7 +1521,7 @@ void MPDConnection::getStatus()
         emitStatusUpdated(sv);
 
         // If playlist length does not match number of IDs, then refresh
-        if (sv.playlistLength!=playQueueIds.length()) {
+        if (sv.playlistLength!=static_cast<size_t>(playQueueIds.length())) {
             playListInfo();
         }
     }
@@ -1502,7 +1531,7 @@ void MPDConnection::getUrlHandlers()
 {
     Response response=sendCommand("urlhandlers");
     if (response.ok) {
-        handlers=MPDParseUtils::parseList(response.data, QByteArray("handler: ")).toSet();
+        handlers=Utils::listToSet(MPDParseUtils::parseList(response.data, QByteArray("handler: ")));
         DBUG << handlers;
     }
 }
@@ -1511,7 +1540,7 @@ void MPDConnection::getTagTypes()
 {
     Response response=sendCommand("tagtypes");
     if (response.ok) {
-        tagTypes=MPDParseUtils::parseList(response.data, QByteArray("tagtype: ")).toSet();
+        tagTypes=Utils::listToSet(MPDParseUtils::parseList(response.data, QByteArray("tagtype: ")));
     }
 }
 
@@ -1673,6 +1702,8 @@ void MPDConnection::parseIdleReturn(const QByteArray &data)
                 getStatus();
                 getReplayGain();
                 statusUpdated=true;
+            } else if (constIdlePartitionValue==value) {
+                listPartitions();
             } else if (constIdleOutputValue==value) {
                 outputs();
             } else if (constIdleStickerValue==value) {
@@ -1687,16 +1718,87 @@ void MPDConnection::parseIdleReturn(const QByteArray &data)
         }
     }
 
+    while (!idleSocketCommandQueue.isEmpty()) {
+        idleSocket.write(idleSocketCommandQueue.dequeue()+'\n');
+        idleSocket.waitForBytesWritten();
+        readReply(idleSocket);
+    }
+
     DBUG << (void *)(&idleSocket) << "write idle";
     idleSocket.write("idle\n");
     idleSocket.waitForBytesWritten();
 }
 
+void MPDConnection::listPartitions()
+{
+    Response response=sendCommand("listpartitions", false);
+    if (response.ok) {
+        emit partitionsUpdated(MPDParseUtils::parsePartitions(response.data));
+    } else {
+        // Send an empty list to indicate lack of partition support for this MPD server.
+        emit partitionsUpdated({});
+    }
+}
+
+void MPDConnection::changePartition(QString name)
+{
+    stopVolumeFade();
+    toggleStopAfterCurrent(false);
+
+    QByteArray cmd = "partition " + encodeName(name);
+    if (sendCommand(cmd).ok) {
+        getStatus();
+        idleSocketCommandQueue.enqueue(cmd);
+        idleSocket.write("noidle\n");
+        idleSocket.waitForBytesWritten();
+    }
+}
+
+void MPDConnection::newPartition(QString name)
+{
+    QByteArray cmd = "newpartition " + encodeName(name);
+    if (sendCommand(cmd).ok) {
+        listPartitions();
+    }
+}
+
+void MPDConnection::delPartition(QString name)
+{
+    QByteArray cmd = "delpartition " + encodeName(name);
+    if (sendCommand(cmd).ok) {
+        listPartitions();
+    }
+}
+
 void MPDConnection::outputs()
 {
     Response response=sendCommand("outputs");
     if (response.ok) {
-        emit outputsUpdated(MPDParseUtils::parseOuputs(response.data));
+        QList<Output> outputs = MPDParseUtils::parseOuputs(response.data);
+
+        // We need to temporarily switch to the default partition in order
+        // to collect the details of all available outputs.
+        if (!details.partition.isEmpty() && details.partition != "default") {
+            QByteArray returnCmd = "partition " + encodeName(details.partition);
+            Response defaultResponse=sendCommand("command_list_begin\npartition default\noutputs\n" + returnCmd + "\ncommand_list_end");
+            if (defaultResponse.ok) {
+                QSet<QString> existingNames;
+                for (const Output &o: outputs) {
+                    existingNames << o.name;
+                }
+                QList<Output> defaultOutputs = MPDParseUtils::parseOuputs(defaultResponse.data);
+                for (Output &o: defaultOutputs) {
+                    if (!existingNames.contains(o.name)) {
+                        o.inCurrentPartition = false;
+                        outputs << o;
+                    }
+                }
+            } else {
+                sendCommand(returnCmd);
+            }
+        }
+
+        emit outputsUpdated(outputs);
     }
 }
 
@@ -1707,6 +1809,13 @@ void MPDConnection::enableOutput(quint32 id, bool enable)
     }
 }
 
+void MPDConnection::moveOutput(QString name)
+{
+    if (sendCommand("moveoutput " + encodeName(name)).ok) {
+        outputs();
+    }
+}
+
 /*
  * Admin commands
  */
@@ -1933,7 +2042,11 @@ void MPDConnection::search(const QString &field, const QString &value, int id)
     if (field==constModifiedSince) {
         time_t v=0;
         if (QRegExp("\\d*").exactMatch(value)) {
+            #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+            v=QDateTime::currentDateTime().date().startOfDay().toTime_t()-(value.toInt()*24*60*60);
+            #else
             v=QDateTime(QDateTime::currentDateTime().date()).toTime_t()-(value.toInt()*24*60*60);
+            #endif
         } else if (QRegExp("^((19|20)\\d\\d)[-/](0[1-9]|1[012])[-/](0[1-9]|[12][0-9]|3[01])$").exactMatch(value)) {
             QDateTime dt=QDateTime::fromString(QString(value).replace("/", "-"), Qt::ISODate);
             if (dt.isValid()) {
@@ -2033,7 +2146,7 @@ void MPDConnection::listStreams()
         QList<Song> songs=MPDParseUtils::parseSongs(response.data, MPDParseUtils::Loc_Streams);
         for (const Song &song: songs) {
             streams.append(Stream(song.file, song.name()));
-        }    
+        }
     }
     clearError();
     emit streamList(streams);
@@ -2097,7 +2210,7 @@ void MPDConnection::sendDynamicMessage(const QStringList &msg)
     // Check whether cantata-dynamic is still alive, by seeing if its channel is still open...
     if (1==msg.count() && QLatin1String("ping")==msg.at(0)) {
         Response response=sendCommand("channels");
-        if (!response.ok || !MPDParseUtils::parseList(response.data, QByteArray("channel: ")).toSet().contains(constDynamicIn)) {
+        if (!response.ok || !(Utils::listToSet(MPDParseUtils::parseList(response.data, QByteArray("channel: ")))).contains(constDynamicIn)) {
             emit dynamicSupport(false);
         }
         return;
@@ -2209,13 +2322,21 @@ bool MPDConnection::recursivelyListDir(const QString &dir, QList<Song> &songs)
                                     : ("lsinfo "+encodeName(dir)));
     if (response.ok) {
         QStringList subDirs;
-        MPDParseUtils::parseDirItems(response.data, details.dir, ver, songs, dir, subDirs, MPDParseUtils::Loc_Library);
-        if (songs.count()>=200){
-            QCoreApplication::processEvents();
-            QList<Song> *copy=new QList<Song>();
-            *copy << songs;
-            emit librarySongs(copy);
-            songs.clear();
+        QList<Song> dirSongs;
+        MPDParseUtils::parseDirItems(response.data, details.dir, ver, dirSongs, dir, subDirs, MPDParseUtils::Loc_Library);
+        // If we have only 1 sug dir and its ".cue" then this is (probably) MPD's trat CUE as a directory
+        // therefore we ignore any files in this directory as they will be the source files of the CUE
+        if (1!=subDirs.size() || !subDirs.at(0).endsWith(".cue")) {
+            songs+=dirSongs;
+            if (songs.count()>=200){
+                QCoreApplication::processEvents();
+                QList<Song> *copy=new QList<Song>();
+                *copy << songs;
+                emit librarySongs(copy);
+                songs.clear();
+            }
+        } else {
+            DBUG << "IGNORING:" << dirSongs.size() << "track(s) as they are source files of cue?" << subDirs.at(0);
         }
         for (const QString &sub: subDirs) {
             recursivelyListDir(sub, songs);
@@ -2241,7 +2362,7 @@ QStringList MPDConnection::getPlaylistFiles(const QString &name)
         emit playlistInfoRetrieved(name, songs);
         for (const Song &s: songs) {
             files.append(s.file);
-        }    
+        }
     }
     return files;
 }
@@ -2275,7 +2396,7 @@ bool MPDConnection::checkRemoteDynamicSupport()
             idleSocket.waitForBytesWritten(constSocketCommsTimeout);
             response=readReply(idleSocket);
             if (response.ok) {
-                return MPDParseUtils::parseList(response.data, QByteArray("channel: ")).toSet().contains(constDynamicIn);
+                return Utils::listToSet(MPDParseUtils::parseList(response.data, QByteArray("channel: "))).contains(constDynamicIn);
             }
         }
     }
@@ -2331,7 +2452,7 @@ void MPDConnection::readRemoteDynamicMessages()
                         for (const QString &m: messages[channel]) {
                             if (!m.isEmpty()) {
                                 DBUG << "Received message " << m;
-                                QStringList parts=m.split(':', QString::SkipEmptyParts);
+                                QStringList parts=m.split(':', CANTATA_SKIP_EMPTY);
                                 QStringList message;
                                 for (QString part: parts) {
                                     part=part.replace("{c}", ":");
@@ -2457,7 +2578,7 @@ void MPDConnection::getStickerSupport()
 {
     Response response=sendCommand("commands");
     canUseStickers=response.ok &&
-        MPDParseUtils::parseList(response.data, QByteArray("command: ")).toSet().contains("sticker");
+        Utils::listToSet(MPDParseUtils::parseList(response.data, QByteArray("command: "))).contains("sticker");
 }
 
 bool MPDConnection::fadingVolume()
@@ -2644,7 +2765,7 @@ void MPDServerInfo::detect() {
         MPDConnection::Response response=conn->sendCommand(lsinfoCommand, false, false);
         QList<QByteArray> lines = response.data.split('\n');
         bool match = false;
-        int indx;
+        unsigned int indx;
         for (const QByteArray &line: lines) {
             for (indx=0; indx<sizeof(lsinfoResponseParameters)/sizeof(ResponseParameter); ++indx) {
                 ResponseParameter &rp = lsinfoResponseParameters[indx];
@@ -2681,9 +2802,9 @@ void MPDServerInfo::detect() {
 
         QByteArray message = "sendmessage rating \"";
         message += "rating ";                           // sticker name
-        message += QString().number(Song::Rating_Max);  // max rating
+        message += QString().number(Song::Rating_Max).toUtf8();  // max rating
         message += " ";
-        message += QString().number(Song::Rating_Step); // rating step (optional)
+        message += QString().number(Song::Rating_Step).toUtf8(); // rating step (optional)
         message += "\"";
         conn->sendCommand(message, false, false);
     }
