@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -32,14 +32,17 @@
 #include <QHostAddress>
 #include <QNetworkProxy>
 #include <QStringList>
+#include <QQueue>
 #include <QSet>
 #include "mpdstats.h"
 #include "mpdstatus.h"
 #include "song.h"
+#include "partition.h"
 #include "output.h"
 #include "playlist.h"
 #include "stream.h"
 #include "config.h"
+#include "support/utils.h"
 #include <time.h>
 
 class QTimer;
@@ -149,7 +152,7 @@ struct MPDConnectionDetails {
     MPDConnectionDetails & operator=(const MPDConnectionDetails &o);
     bool operator==(const MPDConnectionDetails &o) const { return hostname==o.hostname && isLocal()==o.isLocal() && (isLocal() || port==o.port) && password==o.password; }
     bool operator!=(const MPDConnectionDetails &o) const { return !(*this==o); }
-    bool operator<(const MPDConnectionDetails &o) const { return name.localeAwareCompare(o.name)<0; }
+    bool operator<(const MPDConnectionDetails &o) const { return Utils::compare(name, o.name)<0; }
     static QString configGroupName(const QString &n=QString()) { return n.isEmpty() ? "Connection" : ("Connection-"+n); }
     void setDirReadable();
 
@@ -157,6 +160,7 @@ struct MPDConnectionDetails {
     QString hostname;
     quint16 port;
     QString password;
+    QString partition;
     QString dir;
     bool dirReadable;
     #ifdef ENABLE_HTTP_STREAM_PLAYBACK
@@ -266,6 +270,7 @@ public:
     void setDirReadable() { details.setDirReadable(); }
     bool isConnected() const { return State_Connected==state; }
     bool canUsePriority() const { return ver>=CANTATA_MAKE_VERSION(0, 17, 0) && isMpd(); }
+    bool canUsePartitions() const { return ver>=CANTATA_MAKE_VERSION(0, 22, 0) && isMpd(); }
     const QSet<QString> & urlHandlers() const { return handlers; }
     const QSet<QString> & tags() const { return tagTypes; }
     bool composerTagSupported() const { return tagTypes.contains(QLatin1String("Composer")); }
@@ -333,9 +338,16 @@ public Q_SLOTS:
     void stopPlaying(bool afterCurrent=false);
     void clearStopAfter();
 
+    // Partition
+    void listPartitions();
+    void changePartition(QString name);
+    void newPartition(QString name);
+    void delPartition(QString name);
+
     // Output
     void outputs();
     void enableOutput(quint32 id, bool enable);
+    void moveOutput(QString name);
 
     // Miscellaneous
     void getStats();
@@ -394,6 +406,7 @@ Q_SIGNALS:
     void playlistUpdated(const QList<Song> &songs, bool isComplete);
     void statsUpdated(const MPDStatsValues &stats);
     void statusUpdated(const MPDStatusValues &status);
+    void partitionsUpdated(const QList<Partition> &partitions);
     void outputsUpdated(const QList<Output> &outputs);
     void librarySongs(QList<Song> *songs);
     void folderContents(const QString &folder, const QStringList &subFolders, const QList<Song> &songs);
@@ -498,6 +511,7 @@ private:
     MpdSocket idleSocket;
     QTimer *connTimer;
     QByteArray dynamicId;
+    QQueue<QByteArray> idleSocketCommandQueue;
 
     // The three items are used so that we can do quick playqueue updates...
     QList<qint32> playQueueIds;
