@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -25,6 +25,7 @@
 #define MPD_USER_H
 
 #include <QString>
+#include <QMutex>
 #include "mpdconnection.h"
 
 class MPDUser
@@ -51,12 +52,14 @@ public:
 private:
     void init(bool create);
     int getPid();
+    void killProcess();
     bool controlMpd(bool stop);
 
 private:
     QString mpdExe;
     QString pidFileName;
     MPDConnectionDetails det;
+    QMutex mutex;
 };
 
 #endif
