@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -27,6 +27,7 @@
 #ifndef OUTPUT_H
 #define OUTPUT_H
 
+#include "support/utils.h"
 #include <QString>
 
 struct Output
@@ -39,18 +40,20 @@ struct Output
     Output & operator=(const Output &o) {
         id=o.id;
         enabled=o.enabled;
+        inCurrentPartition=o.inCurrentPartition;
         name=o.name;
         return *this;
     }
 
     bool operator<(const Output &o) const {
-        return name.localeAwareCompare(o.name)<0;
+        return Utils::compare(name, o.name)<0;
     }
 
     virtual ~Output() { }
 
     quint32 id;
     bool enabled;
+    bool inCurrentPartition{true};
     QString name;
 };
 
