@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -30,6 +30,7 @@
 #if !defined CANTATA_NO_UI_FUNCTIONS
 #include "online/onlineservice.h"
 #include "online/podcastservice.h"
+#include "support/utils.h"
 #endif
 #include <QStringList>
 #include <QSet>
@@ -41,7 +42,14 @@
 #include <QMutexLocker>
 #include <algorithm>
 
+#if defined CANTATA_NO_UI_FUNCTIONS
+#define COMPARE(A, B) A.localeAwareCompare(B)
+#else
+#define COMPARE(A, B) Utils::compare(A, B)
+#endif
+
 //static const quint8 constOnlineDiscId=0xEE;
+static const QString constMpdQueue=QLatin1String(".cue/track"); // .cue.track0123
 
 const QString Song::constCddaProtocol=QLatin1String("/[cantata-cdda]/");
 const QString Song::constMopidyLocal=QLatin1String("local:track:");
@@ -236,21 +244,21 @@ int Song::compareTo(const Song &o) const
     // For playlists, we only need to compare filename...
     if (Playlist!=type) {
         if (SingleTracks==type) {
-            int compare=artistSong().localeAwareCompare(artistSong());
+            int compare=COMPARE(artistSong(), o.artistSong());
             if (0!=compare) {
                 return compare<0;
             }
         }
 
-        int compare=albumArtistOrComposer().localeAwareCompare(o.albumArtistOrComposer());
+        int compare=COMPARE(albumArtistOrComposer(), o.albumArtistOrComposer());
         if (0!=compare) {
             return compare;
         }
-        compare=album.localeAwareCompare(o.album);
+        compare=COMPARE(album, o.album);
         if (0!=compare) {
             return compare;
         }
-        compare=mbAlbumId().compare(o.mbAlbumId());
+        compare=COMPARE(mbAlbumId(), o.mbAlbumId());
         if (0!=compare) {
             return compare;
         }
@@ -275,11 +283,11 @@ int Song::compareTo(const Song &o) const
                 return origYear<o.origYear ? -1 : 1;
             }
         }
-        compare=title.localeAwareCompare(o.title);
+        compare=COMPARE(title, o.title);
         if (0!=compare) {
             return compare;
         }
-        compare=name().compare(o.name());
+        compare=COMPARE(name(), o.name());
         if (0!=compare) {
             return compare;
         }
@@ -310,14 +318,14 @@ void Song::guessTags()
     if (isEmpty() && !isStream()) {
         static const QLatin1String constAlbumArtistSep(" - ");
         guessed=true;
-        QStringList parts = file.split("/", QString::SkipEmptyParts);
+        QStringList parts = file.split("/", CANTATA_SKIP_EMPTY);
         if (3==parts.length()) {
             title=parts.at(2);
             album=parts.at(1);
             artist=parts.at(0);
         } else if (2==parts.length() && parts.at(0).contains(constAlbumArtistSep)) {
             title=parts.at(1);
-            QStringList albumArtistParts = parts.at(0).split(constAlbumArtistSep, QString::SkipEmptyParts);
+            QStringList albumArtistParts = parts.at(0).split(constAlbumArtistSep, CANTATA_SKIP_EMPTY);
             if (2==albumArtistParts.length()) {
                 album=albumArtistParts.at(1);
                 artist=albumArtistParts.at(0);
@@ -573,7 +581,7 @@ QString Song::artistSong() const
 QString Song::trackAndTitleStr(bool showArtistIfDifferent) const
 {
     #if !defined CANTATA_NO_UI_FUNCTIONS
-    if ((OnlineSvrTrack==type || Song::CantataStream) && OnlineService::showLogoAsCover(*this)) {
+    if ((OnlineSvrTrack==type || CantataStream==type) && OnlineService::showLogoAsCover(*this)) {
         return artistSong();
     }
     #endif
@@ -624,6 +632,7 @@ QString Song::toolTip() const
     if (origYear>0) {
         addField(QObject::tr("Original Year"), QString::number(origYear), toolTip);
     }
+    addField(QObject::tr("Grouping"), grouping(), toolTip);
     if (time>0) {
         addField(QObject::tr("Length"), Utils::formatTime(time, true), toolTip);
     }
@@ -656,7 +665,7 @@ int Song::compareGenres(const Song &o) const
     return 0;
 }
 
-void Song::setExtraField(quint16 f, const QString &v)
+void Song::setExtraField(quint32 f, const QString &v)
 {
     if (v.isEmpty()) {
         extra.remove(f);
@@ -717,7 +726,7 @@ QString Song::capitalize(const QString &s)
         return s;
     }
 
-    QStringList words = s.split(' ', QString::SkipEmptyParts);
+    QStringList words = s.split(' ', CANTATA_SKIP_EMPTY);
     for (int i = 0; i < words.count(); i++) {
         QString word = words[i]; //.toLower();
         int j = 0;
@@ -761,7 +770,7 @@ bool Song::capitalise()
 QString Song::albumKey() const
 {
     #if !defined CANTATA_NO_UI_FUNCTIONS
-    if ((OnlineSvrTrack==type || Song::CantataStream) && OnlineService::showLogoAsCover(*this)) {
+    if ((OnlineSvrTrack==type || CantataStream==type) && OnlineService::showLogoAsCover(*this)) {
         return onlineService();
     }
     #endif
@@ -816,6 +825,11 @@ QString Song::filePath(const QString &base) const
         return file;
     }
     QString fileName=decodePath(file, isCdda());
+    int mpdCueIdx = fileName.indexOf(constMpdQueue);
+    if (mpdCueIdx == fileName.length()-(constMpdQueue.length()+4))
+    {
+        fileName=fileName.mid(0, mpdCueIdx+4);
+    }
     if (!base.isEmpty() && !fileName.isEmpty() && !isNonMPD()) {
         bool haveAbsPath=fileName.startsWith("/") || fileName.contains(":/");
         if (!haveAbsPath) {
@@ -825,6 +839,24 @@ QString Song::filePath(const QString &base) const
     return fileName;
 }
 
+bool Song::isMpdCueTrack() const
+{
+    return file.indexOf(constMpdQueue)==file.length()-(constMpdQueue.length()+4);
+}
+
+QString Song::getDir() const
+{
+    #ifdef CANTATA_NO_UI_FUNCTIONS
+    return QString();
+    #else
+    QString dir = Utils::getDir(file);
+    if (isMpdCueTrack() && dir.endsWith(".cue/")) {
+        dir = Utils::getDir(dir.left(dir.length()-1));
+    }
+    return dir;
+    #endif
+}
+
 QString Song::describe() const
 {
     #if !defined CANTATA_NO_UI_FUNCTIONS
