@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -76,7 +76,7 @@ Song MagnatuneXmlParser::parseSong(QXmlStreamReader &xml)
             } else if (QLatin1String("year")==name) {
                 s.year=value.toInt();
             } else  if (QLatin1String("magnatunegenres")==name) {
-                QStringList genres=value.split(',', QString::SkipEmptyParts);
+                QStringList genres=value.split(',', CANTATA_SKIP_EMPTY);
 //                for (const QString &g: genres) {
 //                    s.addGenre(g);
 //                }
