@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -28,6 +28,7 @@
 #include "support/utils.h"
 #include "support/monoicon.h"
 #include "gui/settings.h"
+#include "gui/stdactions.h"
 #include "widgets/icons.h"
 #include "mpd-interface/mpdconnection.h"
 #include "config.h"
@@ -47,6 +48,7 @@
 #include <QMimeData>
 #include <QDateTime>
 #include <QTextDocument>
+#include <QLocale>
 #include <stdio.h>
 
 GLOBAL_STATIC(PodcastService, instance)
@@ -62,7 +64,7 @@ static QString encodeName(const QString &name)
 
 static inline QString episodeFileName(const QUrl &url)
 {
-    return url.path().split('/', QString::SkipEmptyParts).join('_').replace('~', '_');
+    return url.path().split('/', CANTATA_SKIP_EMPTY).join('_').replace('~', '_');
 }
 
 PodcastService::Proxy::Proxy(QObject *parent)
@@ -426,6 +428,7 @@ PodcastService::PodcastService()
     useCovers(name(), true);
     clearPartialDownloads();
     connect(MPDConnection::self(), SIGNAL(currentSongUpdated(const Song &)), this, SLOT(currentMpdSong(const Song &)));
+    refreshAction = new Action(Icons::self()->reloadIcon, tr("Refresh"), this);
 }
 
 QString PodcastService::name() const
@@ -576,6 +579,11 @@ QVariant PodcastService::data(const QModelIndex &index, int role) const
         Podcast *podcast=static_cast<Podcast *>(item);
 
         switch(role) {
+        case Cantata::Role_Actions: {
+            QVariant v;
+            v.setValue<QList<Action *> >(QList<Action *>() << StdActions::self()->replacePlayQueueAction << StdActions::self()->appendToPlayQueueAction << refreshAction);
+            return v;
+        }
         case Cantata::Role_ListImage:
             return true;
         case Cantata::Role_CoverSong: {
@@ -630,7 +638,7 @@ QVariant PodcastService::data(const QModelIndex &index, int role) const
                 return Utils::formatTime(episode->duration, true)+QLatin1Char(' ')+
                        tr("(Downloading: %1%)").arg(episode->downloadProg);
             }
-            return episode->publishedDate.toString(Qt::LocalDate)+
+            return QLocale().toString(episode->publishedDate, QLocale::LongFormat)+
                         (0==episode->duration
                             ? QString()
                             : (QLatin1String(" (")+Utils::formatTime(episode->duration, true)+QLatin1Char(')')));
@@ -640,7 +648,7 @@ QVariant PodcastService::data(const QModelIndex &index, int role) const
                         episode->name+QLatin1String("<br/>")+
                         trimDescr(episode->descr)+
                         Utils::formatTime(episode->duration, true)+QLatin1String("<br/>")+
-                        episode->publishedDate.toString(Qt::LocalDate);
+                        QLocale().toString(episode->publishedDate, QLocale::LongFormat);
             }
             break;
         case Qt::FontRole:
