@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -162,6 +162,7 @@ public:
     void startRssUpdateTimer();
     void stopRssUpdateTimer();
     bool exportSubscriptions(const QString &name);
+    Action * refreshAct() { return refreshAction; }
 
 Q_SIGNALS:
     void error(const QString &msg);
@@ -203,9 +204,9 @@ private:
     QList<DownloadEntry> toDownload;
     QTimer *rssUpdateTimer;
     QDateTime lastRssUpdate;
-    QTimer *deleteTimer;
     QDateTime lastDelete;
     QSet<QUrl> updateUrls;
+    Action *refreshAction;
     static QString iconFile;
 };
 
