@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -68,6 +68,7 @@ PodcastWidget::PodcastWidget(PodcastService *s, QWidget *p)
     connect(markAsListenedAction, SIGNAL(triggered()), this, SLOT(markAsListened()));
     //connect(unplayedOnlyAction, SIGNAL(toggled(bool)), this, SLOT(showUnplayedOnly(bool)));
     connect(exportAction, SIGNAL(triggered()), SLOT(exportSubscriptions()));
+    connect(srv->refreshAct(), SIGNAL(triggered()), this, SLOT(refreshPodcast()));
 
     view->setMode(ItemView::Mode_DetailedTree);
     Configuration config(metaObject()->className());
@@ -200,7 +201,7 @@ void PodcastWidget::download()
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator it(urls.constBegin());
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator end(urls.constEnd());
         for (; it!=end; ++it) {
-            srv->downloadPodcasts(it.key(), it.value().toList());
+            srv->downloadPodcasts(it.key(), it.value().values());
         }
     }
 }
@@ -223,7 +224,7 @@ void PodcastWidget::deleteDownload()
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator it(urls.constBegin());
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator end(urls.constEnd());
         for (; it!=end; ++it) {
-            srv->deleteDownloadedPodcasts(it.key(), it.value().toList());
+            srv->deleteDownloadedPodcasts(it.key(), it.value().values());
         }
     }
 }
@@ -236,7 +237,7 @@ void PodcastWidget::markAsNew()
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator it(urls.constBegin());
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator end(urls.constEnd());
         for (; it!=end; ++it) {
-            srv->setPodcastsAsListened(it.key(), it.value().toList(), false);
+            srv->setPodcastsAsListened(it.key(), it.value().values(), false);
         }
     }
 }
@@ -249,7 +250,7 @@ void PodcastWidget::markAsListened()
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator it(urls.constBegin());
         QMap<PodcastService::Podcast *, QSet<PodcastService::Episode *> >::ConstIterator end(urls.constEnd());
         for (; it!=end; ++it) {
-            srv->setPodcastsAsListened(it.key(), it.value().toList(), true);
+            srv->setPodcastsAsListened(it.key(), it.value().values(), true);
         }
     }
 }
@@ -271,7 +272,17 @@ void PodcastWidget::doSearch()
     }
 }
 
+void PodcastWidget::refreshPodcast()
+{
+    doRefresh(true);
+}
+
 void PodcastWidget::refresh()
+{
+    doRefresh(false);
+}
+
+void PodcastWidget::doRefresh(bool singleOnly)
 {
     QModelIndexList sel=view->selectedIndexes(false);
     QModelIndexList selected;
@@ -281,6 +292,13 @@ void PodcastWidget::refresh()
         }
     }
 
+    if (singleOnly) {
+        if (1==selected.count()) {
+            srv->refresh(selected);
+        }
+        return;
+    }
+
     if (selected.isEmpty() || selected.count()==srv->podcastCount()) {
         srv->refreshAll();
         return;
