@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -52,10 +52,12 @@ private Q_SLOTS:
     //void showUnplayedOnly(bool on);
     void configure();
     void exportSubscriptions();
+    void refreshPodcast();
 
 private:
     void doSearch() override;
     void refresh() override;
+    void doRefresh(bool singleOnly);
     void controlActions() override;
 
 private:
