@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -132,7 +132,6 @@ DynamicPlaylists::DynamicPlaylists()
     , remoteTimer(nullptr)
     , remotePollingEnabled(false)
     , statusTime(0)
-    , currentJob(nullptr)
     , currentCommand(Unknown)
 {
     connect(this, SIGNAL(clear()), MPDConnection::self(), SLOT(clear()));
@@ -402,7 +401,7 @@ void DynamicPlaylists::parseRemote(const QStringList &response)
     Rule r;
 
     for (const QString &part: response) {
-        QStringList lines=part.split('\n', QString::SkipEmptyParts);
+        QStringList lines=part.split('\n', CANTATA_SKIP_EMPTY);
         for (const QString &s: lines) {
             QString str=s.trimmed();
             if (str.isEmpty() || str.startsWith('#')) {
