@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -34,7 +34,6 @@
 #include "support/icon.h"
 
 class QTimer;
-class NetworkJob;
 
 class DynamicPlaylists : public RulesPlaylists
 {
@@ -118,7 +117,6 @@ private:
     int statusTime;
     QString lastState;
     QString dynamicUrl;
-    NetworkJob *currentJob;
     Command currentCommand;
     QString currentDelete;
     Entry currentSave;
