@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -323,7 +323,7 @@ void RulesPlaylists::loadLocal()
                 Rule r;
                 QTextStream in(&f);
                 in.setCodec("UTF-8");
-                QStringList lines = in.readAll().split('\n', QString::SkipEmptyParts);
+                QStringList lines = in.readAll().split('\n', CANTATA_SKIP_EMPTY);
                 for (const QString &line: lines) {
                     QString str=line.trimmed();
 
