@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -27,6 +27,7 @@
 #include "widgets/icons.h"
 #include "support/action.h"
 #include "support/configuration.h"
+#include "support/utils.h"
 #include "mpd-interface/mpdconnection.h"
 #include "support/messagebox.h"
 #include "gui/stdactions.h"
@@ -157,14 +158,14 @@ void SmartPlaylistsPage::enableWidgets(bool enable)
 
 void SmartPlaylistsPage::searchResponse(const QString &id, const QList<Song> &songs)
 {
-    if (id.length()<3 || id.mid(2).toInt()!=command.id || command.isEmpty()) {
+    if (id.length()<3 || id.mid(2).toUInt()!=command.id || command.isEmpty()) {
         return;
     }
 
     if (id.startsWith("I:")) {
-        command.songs.unite(songs.toSet());
+        command.songs.unite(Utils::listToSet(songs));
     } else if (id.startsWith("E:")) {
-        command.songs.subtract(songs.toSet());
+        command.songs.subtract(Utils::listToSet(songs));
     }
 
     if (command.includeRules.isEmpty()) {
@@ -251,7 +252,7 @@ static bool composerSort(const Song &s1, const Song &s2)
 {
     const QString v1=s1.hasComposer() ? s1.composer() : QString();
     const QString v2=s2.hasComposer() ? s2.composer() : QString();
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
 
@@ -259,7 +260,7 @@ static bool artistSort(const Song &s1, const Song &s2)
 {
     const QString v1=s1.hasArtistSort() ? s1.artistSort() : s1.artist;
     const QString v2=s2.hasArtistSort() ? s2.artistSort() : s2.artist;
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
 
@@ -267,7 +268,7 @@ static bool albumArtistSort(const Song &s1, const Song &s2)
 {
     const QString v1=s1.hasAlbumArtistSort() ? s1.albumArtistSort() : s1.albumArtistOrComposer();
     const QString v2=s2.hasAlbumArtistSort() ? s2.albumArtistSort() : s2.albumArtistOrComposer();
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
 
@@ -275,7 +276,7 @@ static bool albumSort(const Song &s1, const Song &s2)
 {
     const QString v1=s1.hasAlbumSort() ? s1.albumSort() : s1.album;
     const QString v2=s2.hasAlbumSort() ? s2.albumSort() : s2.album;
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
 
@@ -283,7 +284,7 @@ static bool titleSort(const Song &s1, const Song &s2)
 {
     const QString v1=s1.title;
     const QString v2=s2.title;
-    int c=v1.localeAwareCompare(v2);
+    int c=Utils::compare(v1, v2);
     return sortAscending ? (c<0 || (c==0 && s1<s2)) : (c>0 || (c==0 && s1<s2));
 }
 
@@ -318,7 +319,7 @@ void SmartPlaylistsPage::addSongsToPlayQueue()
         return;
     }
 
-    QList<Song> songs = command.songs.toList();
+    QList<Song> songs = command.songs.values();
     command.songs.clear();
 
     sortAscending = command.orderAscending;
@@ -440,7 +441,7 @@ void SmartPlaylistsPage::addSelectionToPlaylist(const QString &name, int action,
                        RulesPlaylists::constCommentKey==rIt.key() || RulesPlaylists::constTitleKey==rIt.key() ||
                        RulesPlaylists::constSimilarArtistsKey==rIt.key() || RulesPlaylists::constGenreKey==rIt.key() ||
                        RulesPlaylists::constFileKey==rIt.key()) {
-                baseRule += " " + rIt.key() + " " + MPDConnection::encodeName(rIt.value());
+                baseRule += " " + rIt.key().toUtf8() + " " + MPDConnection::encodeName(rIt.value());
             } else if (RulesPlaylists::constExactKey==rIt.key()) {
                 if ("false" == rIt.value()) {
                     match = "search";
