@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * This file contains code from QMPDClient:
  * Copyright (C) 2005-2008 Håvard Tautra Knutsen <havtknut@tihlde.org>
@@ -169,7 +169,6 @@ Scrobbler::Scrobbler()
     , lastNowPlaying(0)
     , nowPlayingIsPending(false)
     , lovePending(false)
-    , lastScrobbleFailed(false)
     , nowPlayingSent(false)
     , loveSent(false)
     , scrobbledCurrent(false)
@@ -770,8 +769,7 @@ void Scrobbler::mpdStateUpdated(bool songChanged)
     if (isEnabled() && !scrobbleViaMpd) {
         DBUG << songChanged << lastState << MPDStatus::self()->state();
         bool stateChange=songChanged || lastState!=MPDStatus::self()->state();
-        bool isRepeat=!stateChange && MPDState_Playing==MPDStatus::self()->state() &&
-                      MPDStatus::self()->timeElapsed()>=0 && MPDStatus::self()->timeElapsed()<2;
+        bool isRepeat=!stateChange && MPDState_Playing==MPDStatus::self()->state() && MPDStatus::self()->timeElapsed()<2;
         if (!stateChange && !isRepeat) {
             return;
         }
