@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  */
 
 /**************************************************************************
@@ -218,7 +218,7 @@ bool FancyTabProxyStyle::eventFilter(QObject* o, QEvent* e)
 }
 
 FancyTab::FancyTab(FancyTabBar* tabbar)
-    : QWidget(tabbar), tabbar(tabbar), underMouse(false)
+    : QWidget(tabbar), underMouse(false), tabbar(tabbar)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
     setAttribute(Qt::WA_Hover, true);
@@ -490,7 +490,6 @@ FancyTabWidget::FancyTabWidget(QWidget *parent)
     , sideWidget(new QWidget)
     , sideLayout(new QVBoxLayout)
     , topLayout(new QVBoxLayout)
-    , menu(nullptr)
     , proxyStyle(new FancyTabProxyStyle)
 {
     sideLayout->setSpacing(0);
@@ -752,8 +751,8 @@ void FancyTabWidget::recreate()
 
 void FancyTabWidget::setHiddenPages(const QStringList &hidden)
 {
-    QSet<QString> h=hidden.toSet();
-    if (h==hiddenPages().toSet()) {
+    QSet<QString> h = Utils::listToSet(hidden);
+    if (h==Utils::listToSet(hiddenPages())) {
         return;
     }
     bool needToRecreate=false;
