@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /**************************************************************************
@@ -44,7 +44,6 @@
 #include <QScopedPointer>
 #include <QStringList>
 
-class QMenu;
 class QPainter;
 class QSignalMapper;
 class QStackedWidget;
@@ -228,7 +227,6 @@ private:
     QWidget *sideWidget;
     QVBoxLayout *sideLayout;
     QVBoxLayout *topLayout;
-    QMenu *menu;
     QScopedPointer<FancyTabProxyStyle> proxyStyle;
 };
 
