@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -55,6 +55,7 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #endif
+#include <QCollator>
 
 const QLatin1Char Utils::constDirSep('/');
 const QLatin1String Utils::constDirSepStr("/");
@@ -957,7 +958,7 @@ Utils::Desktop Utils::currentDe()
     static int de=-1;
     if (-1==de) {
         de=Other;
-        QSet<QByteArray> desktop=qgetenv("XDG_CURRENT_DESKTOP").toLower().split(':').toSet();
+        QSet<QByteArray> desktop = Utils::listToSet(qgetenv("XDG_CURRENT_DESKTOP").toLower().split(':'));
         if (desktop.contains("unity")) {
             de=Unity;
         } else if (desktop.contains("kde")) {
@@ -1022,6 +1023,10 @@ QColor Utils::monoIconColor()
     return clampColor(QApplication::palette().color(QPalette::Active, QPalette::WindowText));
 }
 
+QSize Utils::minSize(const QSize& fst, const QSize& snd) {
+    return QSize(std::min(fst.width(), snd.width()), std::min(fst.height(), snd.height()));
+}
+
 #ifdef Q_OS_WIN
 // This is down here, because windows.h includes ALL windows stuff - and we get conflicts with MessageBox :-(
 #include <windows.h>
@@ -1058,3 +1063,14 @@ void Utils::raiseWindow(QWidget *w)
     #endif
 }
 
+int Utils::compare(const QString &a, const QString &b)
+{
+    static QCollator *collator = nullptr;
+    if (!collator) {
+        collator=new QCollator();
+        collator->setNumericMode(true);
+        collator->setIgnorePunctuation(true);
+        collator->setCaseSensitivity(Qt::CaseInsensitive);
+    }
+    return collator->compare(a, b);
+}
