@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -51,6 +51,14 @@ namespace Utils
         return (fabs(d1 - d2) < precision);
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    template <typename T>
+    QSet<T> listToSet(const QList<T> &list) { return QSet<T>(list.cbegin(), list.cend()); }
+#else
+    template <typename T>
+    static inline QSet<T> listToSet(const QList<T> &list) { return list.toSet(); }
+#endif
+
     extern QString fixPath(const QString &d, bool ensureEndsInSlash=true);
     #ifdef Q_OS_WIN
     inline QString homeToTilda(const QString &s) { return s; }
@@ -91,6 +99,7 @@ namespace Utils
     inline QString formatNumber(double number, int precision) { return QString::number(number, 'f', precision); }
     extern QString formatDuration(const quint32 totalseconds);
     extern QString formatTime(const quint32 seconds, bool zeroIsUnknown=false);
+    inline QString escapeActionText(const QString &text) { return QString(text).replace(QLatin1String("&"), QLatin1String("&&")); }
 
     extern QString cleanPath(const QString &p);
     extern QString dataDir(const QString &sub=QString(), bool create=false);
@@ -111,6 +120,7 @@ namespace Utils
     extern bool limitedHeight(QWidget *w);
     extern void resizeWindow(QWidget *w, bool preserveWidth=true, bool preserveHeight=true);
     extern void raiseWindow(QWidget *w);
+    extern QSize minSize(const QSize &fst, const QSize &snd);
 
     enum Desktop {
         KDE,
@@ -123,6 +133,7 @@ namespace Utils
     extern QPainterPath buildPath(const QRectF &r, double radius);
     extern QColor clampColor(const QColor &col);
     extern QColor monoIconColor();
+    extern int compare(const QString &a, const QString &b);
 }
 
 #endif
