@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -107,7 +107,7 @@ static QString tString2QString(const TagLib::String &str)
 TagLib::String qString2TString(const QString &str)
 {
     QString val = str.trimmed();
-    return val.isEmpty() ? TagLib::String::null : TagLib::String(val.toUtf8().data(), TagLib::String::UTF8);
+    return TagLib::String(val.toUtf8().data(), TagLib::String::UTF8);
 }
 
 static inline int convertToCantataRating(double r)
@@ -229,11 +229,11 @@ static QPair<int, int> splitDiscNumber(const QString &value)
     int disc;
     int count = 0;
     if (-1!=value.indexOf('/')) {
-        QStringList list = value.split('/', QString::SkipEmptyParts);
+        QStringList list = value.split('/', CANTATA_SKIP_EMPTY);
         disc = list.value(0).toInt();
         count = list.value(1).toInt();
     } else if (-1!=value.indexOf(':')) {
-        QStringList list = value.split(':', QString::SkipEmptyParts);
+        QStringList list = value.split(':', CANTATA_SKIP_EMPTY);
         disc = list.value(0).toInt();
         count = list.value(1).toInt();
     } else {
@@ -516,10 +516,13 @@ static bool writeID3v2Tags(TagLib::ID3v2::Tag *tag, const Song &from, const Song
                 tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
                 for(int i=0; i<Song::constNumGenres; ++i) {
-                    TagLib::ID3v2::TextIdentificationFrame *frame = new TagLib::ID3v2::TextIdentificationFrame("TCON");
-                    tag->addFrame(frame);
-                    DBUG << "add genre" << to.genres[i].trimmed();
-                    frame->setText(qString2TString(to.genres[i].trimmed()));
+                    QString genre = to.genres[i].trimmed();
+                    if (!genre.isEmpty()) {
+                        TagLib::ID3v2::TextIdentificationFrame *frame = new TagLib::ID3v2::TextIdentificationFrame("TCON");
+                        tag->addFrame(frame);
+                        DBUG << "add genre" << genre;
+                        frame->setText(qString2TString(genre));
+                    }
                 }
             }
             changed=true;
@@ -670,7 +673,10 @@ static bool writeAPETags(TagLib::APE::Tag *tag, const Song &from, const Song &to
                 tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
                 for(int i=0; i<Song::constNumGenres; ++i) {
-                    tag->addValue("GENRE", qString2TString(to.genres[i].trimmed()), false);
+                    QString genre = to.genres[i].trimmed();
+                    if (!genre.isEmpty()) {
+                        tag->addValue("GENRE", qString2TString(genre), false);
+                    }
                 }
             }
             changed=true;
@@ -869,7 +875,7 @@ static bool updateVorbisCommentTag(TagLib::Ogg::XiphComment *tag, const char *ta
     if (value.isEmpty()) {
         const TagLib::StringList &list = tag->fieldListMap()[tagName];
         if (!list.isEmpty()) {
-            tag->removeField(tagName);
+            tag->removeFields(tagName);
             return true;
         }
     } else {
@@ -899,12 +905,15 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
             changed=true;
         }
         if (0!=from.compareGenres(to)) {
-            tag->removeField("GENRE");
+            tag->removeFields("GENRE");
             if (to.genres[1].isEmpty()) {
                 tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
                 for(int i=0; i<Song::constNumGenres; ++i) {
-                    tag->addField("GENRE", qString2TString(to.genres[i].trimmed()), false);
+                    QString  genre = to.genres[i].trimmed();
+                    if (!genre.isEmpty()) {
+                        tag->addField("GENRE", qString2TString(genre), false);
+                    }
                 }
             }
             changed=true;
@@ -941,14 +950,14 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
             if (rg.albumMode) {
                 tag->addField("R128_ALBUM_GAIN", toString(toOpusGain(rg.albumGain + opusHeaderGainCurrent - R128_RG_DIFF)));
             } else {
-                tag->removeField("R128_ALBUM_GAIN");
+                tag->removeFields("R128_ALBUM_GAIN");
             }
 #endif
 
-            tag->removeField("REPLAYGAIN_TRACK_GAIN");
-            tag->removeField("REPLAYGAIN_TRACK_PEAK");
-            tag->removeField("REPLAYGAIN_ALBUM_GAIN");
-            tag->removeField("REPLAYGAIN_ALBUM_PEAK");
+            tag->removeFields("REPLAYGAIN_TRACK_GAIN");
+            tag->removeFields("REPLAYGAIN_TRACK_PEAK");
+            tag->removeFields("REPLAYGAIN_ALBUM_GAIN");
+            tag->removeFields("REPLAYGAIN_ALBUM_PEAK");
         } else
         #endif
         {
@@ -959,8 +968,8 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
                 tag->addField("REPLAYGAIN_ALBUM_GAIN", rgs.albumGain);
                 tag->addField("REPLAYGAIN_ALBUM_PEAK", rgs.albumPeak);
             } else {
-                tag->removeField("REPLAYGAIN_ALBUM_GAIN");
-                tag->removeField("REPLAYGAIN_ALBUM_PEAK");
+                tag->removeFields("REPLAYGAIN_ALBUM_GAIN");
+                tag->removeFields("REPLAYGAIN_ALBUM_PEAK");
             }
         }
         changed=true;
@@ -987,20 +996,19 @@ static bool writeVorbisCommentTags(TagLib::Ogg::XiphComment *tag, const Song &fr
 static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImage *img, QString *lyrics, int *rating)
 {
     DBUG;
-    TagLib::MP4::ItemListMap &map = tag->itemListMap();
 
     if (song) {
-        if (map.contains("aART") && !map["aART"].toStringList().isEmpty()) {
-            song->albumartist=tString2QString(map["aART"].toStringList().front());
+        if (tag->contains("aART") && !tag->item("aART").toStringList().isEmpty()) {
+            song->albumartist=tString2QString(tag->item("aART").toStringList().front());
         }
-        if (map.contains("\xA9wrt") && !map["\xA9wrt"].toStringList().isEmpty()) {
-            song->setComposer(tString2QString(map["\xA9wrt"].toStringList().front()));
+        if (tag->contains("\xA9wrt") && !tag->item("\xA9wrt").toStringList().isEmpty()) {
+            song->setComposer(tString2QString(tag->item("\xA9wrt").toStringList().front()));
         }
-        if (map.contains("disk")) {
-            song->disc=map["disk"].toIntPair().first;
+        if (tag->contains("disk")) {
+            song->disc=tag->item("disk").toIntPair().first;
         }
-        if (map.contains("\251gen")) {
-            TagLib::StringList genres=map["\251gen"].toStringList();
+        if (tag->contains("\251gen")) {
+            TagLib::StringList genres=tag->item("\251gen").toStringList();
             TagLib::StringList::ConstIterator it=genres.begin();
             TagLib::StringList::ConstIterator end=genres.end();
             for (; it!=end; ++it) {
@@ -1009,22 +1017,22 @@ static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImag
         }
     }
     if (rg) {
-        if (map.contains("----:com.apple.iTunes:replaygain_track_gain")) {
-            rg->trackGain=parseRgString(map["----:com.apple.iTunes:replaygain_track_gain"].toStringList().front());
+        if (tag->contains("----:com.apple.iTunes:replaygain_track_gain")) {
+            rg->trackGain=parseRgString(tag->item("----:com.apple.iTunes:replaygain_track_gain").toStringList().front());
         }
-        if (map.contains("----:com.apple.iTunes:replaygain_track_peak")) {
-            rg->trackPeak=parseRgString(map["----:com.apple.iTunes:replaygain_track_peak"].toStringList().front());
+        if (tag->contains("----:com.apple.iTunes:replaygain_track_peak")) {
+            rg->trackPeak=parseRgString(tag->item("----:com.apple.iTunes:replaygain_track_peak").toStringList().front());
         }
-        if (map.contains("----:com.apple.iTunes:replaygain_album_gain")) {
-            rg->albumGain=parseRgString(map["----:com.apple.iTunes:replaygain_album_gain"].toStringList().front());
+        if (tag->contains("----:com.apple.iTunes:replaygain_album_gain")) {
+            rg->albumGain=parseRgString(tag->item("----:com.apple.iTunes:replaygain_album_gain").toStringList().front());
         }
-        if (map.contains("----:com.apple.iTunes:replaygain_album_peak")) {
-            rg->albumPeak=parseRgString(map["----:com.apple.iTunes:replaygain_album_peak"].toStringList().front());
+        if (tag->contains("----:com.apple.iTunes:replaygain_album_peak")) {
+            rg->albumPeak=parseRgString(tag->item("----:com.apple.iTunes:replaygain_album_peak").toStringList().front());
         }
     }
     if (img) {
-        if (map.contains("covr")) {
-            TagLib::MP4::Item coverItem = map["covr"];
+        if (tag->contains("covr")) {
+            TagLib::MP4::Item coverItem = tag->item("covr");
             TagLib::MP4::CoverArtList coverArtList = coverItem.toCoverArtList();
             if (!coverArtList.isEmpty()) {
                 TagLib::MP4::CoverArt coverArt = coverArtList.front();
@@ -1034,28 +1042,26 @@ static void readMP4Tags(TagLib::MP4::Tag *tag, Song *song, ReplayGain *rg, QImag
         }
     }
     if (lyrics) {
-        if (map.contains("\251lyr") && !map["\251lyr"].toStringList().isEmpty()) {
-            *lyrics=tString2QString(map["\251lyr"].toStringList().front());
+        if (tag->contains("\251lyr") && !tag->item("\251lyr").toStringList().isEmpty()) {
+            *lyrics=tString2QString(tag->item("\251lyr").toStringList().front());
         }
     }
     if (rating) {
-        if (map.contains("----:com.apple.iTunes:FMPS_Rating")) {
-            *rating=convertToCantataRating(parseDoubleString(map["----:com.apple.iTunes:FMPS_Rating"].toStringList().front()));
+        if (tag->contains("----:com.apple.iTunes:FMPS_Rating")) {
+            *rating=convertToCantataRating(parseDoubleString(tag->item("----:com.apple.iTunes:FMPS_Rating").toStringList().front()));
         }
     }
 }
 
 static bool updateMP4Tag(TagLib::MP4::Tag *tag, const char *tagName, const QString &value)
 {
-    TagLib::MP4::ItemListMap &map = tag->itemListMap();
-
     if (value.isEmpty()) {
-        if (map.contains(tagName)) {
-            map.erase(tagName);
+        if (tag->contains(tagName)) {
+            tag->removeItem(tagName);
             return true;
         }
     } else {
-        map.insert(tagName, TagLib::StringList(qString2TString(value)));
+        tag->setItem(tagName, TagLib::StringList(qString2TString(value)));
         return true;
     }
     return false;
@@ -1082,9 +1088,12 @@ static bool writeMP4Tags(TagLib::MP4::Tag *tag, const Song &from, const Song &to
             } else {
                 TagLib::StringList tagGenres;
                 for(int i=0; i<Song::constNumGenres; ++i) {
-                    tagGenres.append(qString2TString(to.genres[i].trimmed()));
+                    QString genre = to.genres[i].trimmed();
+                    if (!genre.isEmpty()) {
+                        tagGenres.append(qString2TString(genre));
+                    }
                 }
-                tag->itemListMap()["\251gen"]=tagGenres;
+                tag->setItem("\251gen",tagGenres);
             }
             changed=true;
         }
@@ -1092,15 +1101,14 @@ static bool writeMP4Tags(TagLib::MP4::Tag *tag, const Song &from, const Song &to
 
     if (!rg.null) {
         RgTagsStrings rgs(rg);
-        TagLib::MP4::ItemListMap &map = tag->itemListMap();
-        map["----:com.apple.iTunes:replaygain_track_gain"] = TagLib::MP4::Item(TagLib::StringList(rgs.trackGain));
-        map["----:com.apple.iTunes:replaygain_track_peak"] = TagLib::MP4::Item(TagLib::StringList(rgs.trackPeak));
+        tag->setItem("----:com.apple.iTunes:replaygain_track_gain",TagLib::MP4::Item(TagLib::StringList(rgs.trackGain)));
+        tag->setItem("----:com.apple.iTunes:replaygain_track_peak",TagLib::MP4::Item(TagLib::StringList(rgs.trackPeak)));
         if (rg.albumMode) {
-            map["----:com.apple.iTunes:replaygain_album_gain"] = TagLib::MP4::Item(TagLib::StringList(rgs.albumGain));
-            map["----:com.apple.iTunes:replaygain_album_peak"] = TagLib::MP4::Item(TagLib::StringList(rgs.albumPeak));
+            tag->setItem("----:com.apple.iTunes:replaygain_album_gain",TagLib::MP4::Item(TagLib::StringList(rgs.albumGain)));
+            tag->setItem("----:com.apple.iTunes:replaygain_album_peak",TagLib::MP4::Item(TagLib::StringList(rgs.albumPeak)));
         } else {
-            map.erase("----:com.apple.iTunes:replaygain_album_gain");
-            map.erase("----:com.apple.iTunes:replaygain_album_peak");
+            tag->removeItem("----:com.apple.iTunes:replaygain_album_gain");
+            tag->removeItem("----:com.apple.iTunes:replaygain_album_peak");
         }
         changed=true;
     }
@@ -1111,16 +1119,14 @@ static bool writeMP4Tags(TagLib::MP4::Tag *tag, const Song &from, const Song &to
         TagLib::MP4::CoverArtList coverArtList;
         coverArtList.append(coverArt);
         TagLib::MP4::Item coverItem(coverArtList);
-        TagLib::MP4::ItemListMap &map = tag->itemListMap();
-        map.insert("covr", coverItem);
+        tag->setItem("covr",coverItem);
     }
 
     if (rating>-1) {
         int old=-1;
         readMP4Tags(tag, nullptr, nullptr, nullptr, nullptr, &old);
         if (old!=rating) {
-            TagLib::MP4::ItemListMap &map = tag->itemListMap();
-            map["----:com.apple.iTunes:FMPS_Rating"] = TagLib::MP4::Item(TagLib::StringList(convertFromCantataRating(rating)));
+            tag->setItem("----:com.apple.iTunes:FMPS_Rating", TagLib::MP4::Item(TagLib::StringList(convertFromCantataRating(rating))));
             changed=true;
         }
     }
@@ -1201,7 +1207,10 @@ static bool writeASFTags(TagLib::ASF::Tag *tag, const Song &from, const Song &to
                 tag->setGenre(qString2TString(to.firstGenre().trimmed()));
             } else {
                 for(int i=0; i<Song::constNumGenres; ++i) {
-                    tag->addAttribute("WM/Genre", qString2TString(to.genres[i].trimmed()));
+                    QString genre = to.genres[i].trimmed();
+                    if (!genre.isEmpty()) {
+                        tag->addAttribute("WM/Genre", qString2TString(genre));
+                    }
                 }
             }
             changed=true;
@@ -1490,11 +1499,23 @@ static Update update(const TagLib::FileRef fileref, const Song &from, const Song
             bool isID3v24=v2 && isId3V24(v2->header());
             int ver=id3Ver==3 ? 3 : (id3Ver==4 ? 4 : (isID3v24 ? 4 : 3));
             DBUG << "isID3v24" << isID3v24 << "reqVer:" << id3Ver << "use:" << ver;
+
+            #if TAGLIB_VERSION>=CANTATA_MAKE_VERSION(1, 12, 0)
+            return mpeg->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers, TagLib::ID3v2::Version(ver)) ? Update_Modified : Update_Failed;
+            #else
             return mpeg->save(TagLib::MPEG::File::ID3v2, true, ver) ? Update_Modified : Update_Failed;
+            #endif
+
             #else
             Q_UNUSED(id3Ver)
+
+            #if TAGLIB_VERSION>=CANTATA_MAKE_VERSION(1, 12, 0)
+            return mpeg->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers) ? Update_Modified : Update_Failed;
+            #else
             return mpeg->save(TagLib::MPEG::File::ID3v2, true) ? Update_Modified : Update_Failed;
             #endif
+
+            #endif
         }
         return fileref.file()->save() ? Update_Modified : Update_Failed;
     }
@@ -1518,10 +1539,22 @@ Update updateArtistAndTitle(const QString &fileName, const Song &song)
         TagLib::ID3v2::Tag *v2=mpeg->ID3v2Tag(false);
         int ver=v2 && isId3V24(v2->header()) ? 4 : 3;
         DBUG << "useId3ver:" << ver;
+
+        #if TAGLIB_VERSION>=CANTATA_MAKE_VERSION(1, 12, 0)
+        return mpeg->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers, TagLib::ID3v2::Version(ver)) ? Update_Modified : Update_Failed;
+        #else
         return mpeg->save(TagLib::MPEG::File::ID3v2, true, ver) ? Update_Modified : Update_Failed;
+        #endif
+
+        #else
+
+        #if TAGLIB_VERSION>=CANTATA_MAKE_VERSION(1, 12, 0)
+        return mpeg->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers) ? Update_Modified : Update_Failed;
         #else
         return mpeg->save(TagLib::MPEG::File::ID3v2, true) ? Update_Modified : Update_Failed;
         #endif
+
+        #endif
     }
     return fileref.file()->save() ? Update_Modified : Update_Failed;
 }
