@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -35,7 +35,7 @@ public:
         : ComboBox(p) {
         setEditable(true);
         setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
-        setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+        setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
         view()->setTextElideMode(Qt::ElideRight);
     }
 
