@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -96,7 +96,7 @@ public:
         setToolTip("<b>"+mainText->fullText()+"</b><br/>"+subText->fullText());
     }
 
-    void paintEvent(QPaintEvent *e) override
+    void paintEvent(QPaintEvent */*e*/) override
     {
         QStylePainter p(this);
         QStyleOptionToolButton opt;
