@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -220,6 +220,7 @@ void PlayQueueView::setMode(ItemView::Mode m)
         break;
     }
 
+    PlayQueueModel::self()->setSimpleSort(ItemView::Mode_Table==m);
     QAbstractItemModel *model=nullptr;
     QList<QAction *> actions;
     if (ItemView::Mode_Count!=mode) {
@@ -393,7 +394,7 @@ void PlayQueueView::hideSpinner()
     }
 }
 
-void PlayQueueView::setFade(float value)
+void PlayQueueView::setFade(double value)
 {
     if (fadeValue!=value) {
         fadeValue = value;
