@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2018-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2018-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -93,9 +93,9 @@ void VolumeControl::selectControl()
 void VolumeControl::setColor(const QColor &col)
 {
     QColor c=Utils::clampColor(col);
-    mpdVol->setColor(col);
-    httpVol->setColor(col);
-    label->setColor(col);
+    mpdVol->setColor(c);
+    httpVol->setColor(c);
+    label->setColor(c);
 }
 
 void VolumeControl::initActions()
