@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2020 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2022 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -244,7 +244,7 @@ void VolumeSlider::contextMenuEvent(QContextMenuEvent *ev)
 
 void VolumeSlider::wheelEvent(QWheelEvent *ev)
 {
-    int numDegrees = ev->delta() / 8;
+    int numDegrees = ev->angleDelta().y() / 8;
     int numSteps = numDegrees / 15;
     if (numSteps > 0) {
         for (int i = 0; i < numSteps; ++i) {
